@@ -368,7 +368,7 @@ void SAL_CALL BaseControl::createPeer(	const	Reference< XToolkit >&		xToolkit	,
         if ( xLocalToolkit.is() == sal_False )
         {
             // but first create wellknown toolkit, if it not exist
-            xLocalToolkit = Reference< XToolkit > ( m_xFactory->createInstance( OUString::createFromAscii( SERVICE_VCLTOOLKIT ) ), UNO_QUERY );
+            xLocalToolkit = Reference< XToolkit > ( m_xFactory->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM( SERVICE_VCLTOOLKIT )) ), UNO_QUERY );
         }
         m_xPeer			= xLocalToolkit->createWindow( *pDescriptor );
         m_xPeerWindow	= Reference< XWindow >( m_xPeer, UNO_QUERY );
@@ -934,7 +934,7 @@ WindowDescriptor* BaseControl::impl_getWindowDescriptor( const Reference< XWindo
     WindowDescriptor* pDescriptor = new WindowDescriptor ;
 
     pDescriptor->Type				= WindowClass_SIMPLE					;
-    pDescriptor->WindowServiceName	= OUString::createFromAscii( "window" )	;
+    pDescriptor->WindowServiceName	= OUString(RTL_CONSTASCII_USTRINGPARAM("window"))	;
     pDescriptor->ParentIndex		= -1									;
     pDescriptor->Parent				= xParentPeer							;
     pDescriptor->Bounds				= getPosSize ()							;
