@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -39,10 +40,9 @@
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/frame/XDispatch.hpp>
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
-#include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <cppuhelper/typeprovider.hxx>
-#include <vos/diagnose.hxx>
+#include <osl/diagnose.h>
 
 //______________________________________________________________________________________________________________
 //	include of my own project
@@ -310,7 +310,7 @@ const Sequence< OUString > FrameControl::impl_getStaticSupportedServiceNames()
 {
     MutexGuard aGuard( Mutex::getGlobalMutex() );
     Sequence< OUString > seqServiceNames( 1 );
-    seqServiceNames.getArray() [0] = OUString::createFromAscii( SERVICENAME_FRAMECONTROL );
+    seqServiceNames.getArray() [0] = OUString(RTL_CONSTASCII_USTRINGPARAM( SERVICENAME_FRAMECONTROL ));
     return seqServiceNames ;
 }
 
@@ -320,7 +320,7 @@ const Sequence< OUString > FrameControl::impl_getStaticSupportedServiceNames()
 
 const OUString FrameControl::impl_getStaticImplementationName()
 {
-    return OUString::createFromAscii( IMPLEMENTATIONNAME_FRAMECONTROL );
+    return OUString(RTL_CONSTASCII_USTRINGPARAM( IMPLEMENTATIONNAME_FRAMECONTROL ));
 }
 
 //____________________________________________________________________________________________________________
@@ -376,7 +376,7 @@ void FrameControl::setFastPropertyValue_NoBroadcast(			sal_Int32	nHandle	,
         case PROPERTYHANDLE_LOADERARGUMENTS		:		rValue >>= m_seqLoaderArguments ;
                                                         break ;
 
-        default	:										VOS_ENSHURE ( nHandle == -1, ERRORTEXT_VOSENSHURE ) ;
+        default	:										OSL_ENSURE ( nHandle == -1, ERRORTEXT_VOSENSHURE ) ;
     }
 }
 
@@ -400,7 +400,7 @@ void FrameControl::getFastPropertyValue(	Any&		rRet	,
         case PROPERTYHANDLE_FRAME			:		rRet <<= m_xFrame ;
                                                        break ;
 
-        default	:			                        VOS_ENSHURE ( nHandle == -1, ERRORTEXT_VOSENSHURE ) ;
+        default	:			                        OSL_ENSURE ( nHandle == -1, ERRORTEXT_VOSENSHURE ) ;
     }
 }
 
@@ -508,7 +508,7 @@ void FrameControl::impl_createFrame(	const	Reference< XWindowPeer >&	xPeer		,
         xOldFrame = m_xFrame ;
     }
 
-    xNewFrame = Reference< XFrame >  ( impl_getMultiServiceFactory()->createInstance ( OUString::createFromAscii( "com.sun.star.frame.Frame" ) ), UNO_QUERY ) ;
+    xNewFrame = Reference< XFrame >  ( impl_getMultiServiceFactory()->createInstance ( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Frame")) ), UNO_QUERY ) ;
     Reference< XDispatchProvider >  xDSP ( xNewFrame, UNO_QUERY ) ;
 
     if (xDSP.is())
@@ -519,7 +519,7 @@ void FrameControl::impl_createFrame(	const	Reference< XWindowPeer >&	xPeer		,
         //	option
         //xFrame->setName( "WhatYouWant" );
 
-        Reference< XURLTransformer >  xTrans ( impl_getMultiServiceFactory()->createInstance ( OUString::createFromAscii( "com.sun.star.util.URLTransformer" ) ), UNO_QUERY ) ;
+        Reference< XURLTransformer >  xTrans ( impl_getMultiServiceFactory()->createInstance ( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.util.URLTransformer")) ), UNO_QUERY ) ;
         if(xTrans.is())
         {
             // load file
@@ -591,9 +591,9 @@ const Sequence< Property > FrameControl::impl_getStaticPropertyDescriptor()
     // All Properties of this implementation. The array must be sorted!
     static const Property pPropertys[PROPERTY_COUNT] =
     {
-        Property( OUString::createFromAscii( PROPERTYNAME_COMPONENTURL		), PROPERTYHANDLE_COMPONENTURL		, ::getCppuType((const OUString*)0)					, PropertyAttribute::BOUND | PropertyAttribute::CONSTRAINED	),
-        Property( OUString::createFromAscii( PROPERTYNAME_FRAME				), PROPERTYHANDLE_FRAME				, ::getCppuType((const Reference< XFrame >*)0)		, PropertyAttribute::BOUND | PropertyAttribute::TRANSIENT	),
-        Property( OUString::createFromAscii( PROPERTYNAME_LOADERARGUMENTS	), PROPERTYHANDLE_LOADERARGUMENTS	, ::getCppuType((const Sequence< PropertyValue >*)0), PropertyAttribute::BOUND | PropertyAttribute::CONSTRAINED	)
+        Property( OUString(RTL_CONSTASCII_USTRINGPARAM( PROPERTYNAME_COMPONENTURL		)), PROPERTYHANDLE_COMPONENTURL		, ::getCppuType((const OUString*)0)					, PropertyAttribute::BOUND | PropertyAttribute::CONSTRAINED	),
+        Property( OUString(RTL_CONSTASCII_USTRINGPARAM( PROPERTYNAME_FRAME				)), PROPERTYHANDLE_FRAME				, ::getCppuType((const Reference< XFrame >*)0)		, PropertyAttribute::BOUND | PropertyAttribute::TRANSIENT	),
+        Property( OUString(RTL_CONSTASCII_USTRINGPARAM( PROPERTYNAME_LOADERARGUMENTS	)), PROPERTYHANDLE_LOADERARGUMENTS	, ::getCppuType((const Sequence< PropertyValue >*)0), PropertyAttribute::BOUND | PropertyAttribute::CONSTRAINED	)
     };
 
     static const Sequence< Property > seqPropertys( pPropertys, PROPERTY_COUNT );
@@ -602,3 +602,5 @@ const Sequence< Property > FrameControl::impl_getStaticPropertyDescriptor()
 }
 
 }	// namespace unocontrols
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
