@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
@@ -39,7 +40,7 @@
 #include <toolkit/awt/vclxwindow.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <unotools/accessiblestatesethelper.hxx>
 #include <tools/diagnose_ex.h>
 
@@ -128,7 +129,7 @@ namespace accessibility
         {
         public:
             MethodGuard( AccessibleToolPanelDeck_Impl& i_rImpl )
-                :m_aGuard( Application::GetSolarMutex() )
+                :m_aGuard()
             {
                 i_rImpl.checkDisposed();
             }
@@ -136,13 +137,8 @@ namespace accessibility
             {
             }
 
-            void clear()
-            {
-                m_aGuard.clear();
-            }
-
         private:
-            ::vos::OClearableGuard  m_aGuard;
+            SolarMutexGuard  m_aGuard;
         };
     }
 
@@ -410,3 +406,5 @@ namespace accessibility
 //......................................................................................................................
 } // namespace accessibility
 //......................................................................................................................
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
