@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,10 +29,8 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_basctl.hxx"
 
-
 #include <ide_pch.hxx>
 
-
 #include <svtools/texteng.hxx>
 #include <svtools/textview.hxx>
 #include <svtools/xtextedt.hxx>
@@ -50,7 +48,6 @@
 #include <sfx2/docfile.hxx>
 #include <basic/basrdll.hxx>
 
-
 #include <baside2.hrc>
 #include <baside2.hxx>
 #include <objdlg.hxx>
@@ -102,8 +99,8 @@ using namespace comphelper;
 DBG_NAME( ModulWindow )
 
 TYPEINIT1( ModulWindow , IDEBaseWindow );
- 
-void lcl_PrintHeader( Printer* pPrinter, USHORT nPages, USHORT nCurPage, const String& rTitle, bool bOutput )
+
+void lcl_PrintHeader( Printer* pPrinter, sal_uInt16 nPages, sal_uInt16 nCurPage, const String& rTitle, bool bOutput )
 {
     short nLeftMargin 	= LMARGPRN;
     Size aSz = pPrinter->GetOutputSize();
@@ -168,8 +165,8 @@ void lcl_ConvertTabsToSpaces( String& rLine )
 {
     if ( rLine.Len() )
     {
-        USHORT nPos = 0;
-        USHORT nMax = rLine.Len();
+        sal_uInt16 nPos = 0;
+        sal_uInt16 nMax = rLine.Len();
         while ( nPos < nMax )
         {
             if ( rLine.GetChar( nPos ) == '\t' )
@@ -187,7 +184,7 @@ void lcl_ConvertTabsToSpaces( String& rLine )
 }
 
 
-ModulWindow::ModulWindow( ModulWindowLayout* pParent, const ScriptDocument& rDocument, String aLibName, 
+ModulWindow::ModulWindow( ModulWindowLayout* pParent, const ScriptDocument& rDocument, String aLibName,
                           String aName, ::rtl::OUString& aModule )
         :IDEBaseWindow( pParent, rDocument, aLibName, aName )
         ,aXEditorWindow( this )
@@ -203,10 +200,10 @@ ModulWindow::ModulWindow( ModulWindowLayout* pParent, const ScriptDocument& rDoc
 
 SbModuleRef ModulWindow::XModule()
 {
-    // ModuleWindows can now be created as a result of the 
+    // ModuleWindows can now be created as a result of the
     // modules getting created via the api. This is a result of an
     // elementInserted event from the BasicLibrary container.
-    // However the SbModule is also created from a different listener to 
+    // However the SbModule is also created from a different listener to
     // the same event ( in basmgr ) Therefore it is possible when we look
     // for xModule it may not yet be available, here we keep tring to access
     // the module until such time as it exists
@@ -227,7 +224,7 @@ SbModuleRef ModulWindow::XModule()
     return xModule;
 }
 
-__EXPORT ModulWindow::~ModulWindow()
+ModulWindow::~ModulWindow()
 {
     DBG_DTOR( ModulWindow, 0 );
     nValid = 0;
@@ -236,7 +233,7 @@ __EXPORT ModulWindow::~ModulWindow()
 }
 
 
-void __EXPORT ModulWindow::GetFocus()
+void ModulWindow::GetFocus()
 {
     if ( nValid != VALIDWINDOW  )
         return;
@@ -252,17 +249,15 @@ void ModulWindow::DoInit()
     if ( GetVScrollBar() )
         GetVScrollBar()->Hide();
     GetHScrollBar()->Show();
-//	GetEditorWindow().SetScrollBarRanges();
     GetEditorWindow().InitScrollBars();
-//	GetEditorWindow().GrabFocus();
 }
 
 
-void __EXPORT ModulWindow::Paint( const Rectangle& )
+void ModulWindow::Paint( const Rectangle& )
 {
 }
 
-void __EXPORT ModulWindow::Resize()
+void ModulWindow::Resize()
 {
     aXEditorWindow.SetPosSizePixel( Point( 0, 0 ),
                                     Size( GetOutputSizePixel() ) );
@@ -279,13 +274,13 @@ void ModulWindow::CheckCompileBasic()
     if ( XModule().Is() )
     {
         // Zur Laufzeit wird niemals compiliert!
-        BOOL bRunning = StarBASIC::IsRunning();
-        BOOL bModified = ( !xModule->IsCompiled() ||
+        sal_Bool bRunning = StarBASIC::IsRunning();
+        sal_Bool bModified = ( !xModule->IsCompiled() ||
             ( GetEditEngine() && GetEditEngine()->IsModified() ) );
 
         if ( !bRunning && bModified )
         {
-            BOOL bDone = FALSE;
+            sal_Bool bDone = sal_False;
 
             BasicIDEShell* pIDEShell = IDE_DLL()->GetShell();
             pIDEShell->GetViewFrame()->GetWindow().EnterWait();
@@ -293,14 +288,14 @@ void ModulWindow::CheckCompileBasic()
             if( bModified )
             {
                 AssertValidEditEngine();
-                GetEditorWindow().SetSourceInBasic( FALSE );
+                GetEditorWindow().SetSourceInBasic( sal_False );
             }
 
-            BOOL bWasModified = GetBasic()->IsModified();
+            sal_Bool bWasModified = GetBasic()->IsModified();
 
             bDone = GetBasic()->Compile( xModule );
             if ( !bWasModified )
-                GetBasic()->SetModified( FALSE );
+                GetBasic()->SetModified( sal_False );
 
             if ( bDone )
             {
@@ -310,12 +305,12 @@ void ModulWindow::CheckCompileBasic()
             pIDEShell->GetViewFrame()->GetWindow().LeaveWait();
 
             aStatus.bError = !bDone;
-            aStatus.bIsRunning = FALSE;
+            aStatus.bIsRunning = sal_False;
         }
     }
 }
 
-BOOL ModulWindow::BasicExecute()
+sal_Bool ModulWindow::BasicExecute()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
 
@@ -326,7 +321,7 @@ BOOL ModulWindow::BasicExecute()
         if ( !aDocument.allowMacros() )
         {
             WarningBox( this, WB_OK, String( IDEResId( RID_STR_CANNOTRUNMACRO ) ) ).Execute();
-            return FALSE;
+            return sal_False;
         }
     }
 
@@ -334,20 +329,20 @@ BOOL ModulWindow::BasicExecute()
 
     if ( XModule().Is() && xModule->IsCompiled() && !aStatus.bError )
     {
-        if ( GetBreakPoints().Count() )
+        if ( GetBreakPoints().size() )
             aStatus.nBasicFlags = aStatus.nBasicFlags | SbDEBUG_BREAK;
 
         if ( !aStatus.bIsRunning )
         {
             DBG_ASSERT( xModule.Is(), "Kein Modul!" );
             AddStatus( BASWIN_RUNNINGBASIC );
-            USHORT nStart, nEnd, nCurMethodStart = 0;
+            sal_uInt16 nStart, nEnd, nCurMethodStart = 0;
             TextSelection aSel = GetEditView()->GetSelection();
             // Init cursor to top
             nCurMethodStart = ( aSel.GetStart().GetPara() + 1 );
             SbMethod* pMethod = 0;
             // erstes Macro, sonst blind "Main" (ExtSearch?)
-            for ( USHORT nMacro = 0; nMacro < xModule->GetMethods()->Count(); nMacro++ )
+            for ( sal_uInt16 nMacro = 0; nMacro < xModule->GetMethods()->Count(); nMacro++ )
             {
                 SbMethod* pM = (SbMethod*)xModule->GetMethods()->Get( nMacro );
                 DBG_ASSERT( pM, "Method?" );
@@ -362,73 +357,73 @@ BOOL ModulWindow::BasicExecute()
             if ( !pMethod )
             {
                 // If not in a method then prompt the user
-                return ( BasicIDE::ChooseMacro( uno::Reference< frame::XModel >(), FALSE, rtl::OUString() ).getLength() > 0 ) ? TRUE : FALSE;
+                return ( BasicIDE::ChooseMacro( uno::Reference< frame::XModel >(), sal_False, rtl::OUString() ).getLength() > 0 ) ? sal_True : sal_False;
             }
             if ( pMethod )
             {
                 pMethod->SetDebugFlags( aStatus.nBasicFlags );
-                BasicDLL::SetDebugMode( TRUE );
+                BasicDLL::SetDebugMode( sal_True );
                 BasicIDE::RunMethod( pMethod );
-                BasicDLL::SetDebugMode( FALSE );
-                // Falls waehrend Interactive=FALSE abgebrochen
-                BasicDLL::EnableBreak( TRUE );
+                BasicDLL::SetDebugMode( sal_False );
+                // Falls waehrend Interactive=sal_False abgebrochen
+                BasicDLL::EnableBreak( sal_True );
             }
             ClearStatus( BASWIN_RUNNINGBASIC );
         }
         else
-            aStatus.bIsRunning = FALSE;	// Abbruch von Reschedule()
+            aStatus.bIsRunning = sal_False;	// Abbruch von Reschedule()
     }
 
-    BOOL bDone = !aStatus.bError;
+    sal_Bool bDone = !aStatus.bError;
 
     return bDone;
 }
 
-BOOL ModulWindow::CompileBasic()
+sal_Bool ModulWindow::CompileBasic()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     CheckCompileBasic();
 
-    BOOL bIsCompiled = FALSE;
+    sal_Bool bIsCompiled = sal_False;
     if ( XModule().Is() )
         bIsCompiled = xModule->IsCompiled();
 
     return bIsCompiled;
 }
 
-BOOL ModulWindow::BasicRun()
+sal_Bool ModulWindow::BasicRun()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
 
     aStatus.nBasicFlags = 0;
-    BOOL bDone = BasicExecute();
+    sal_Bool bDone = BasicExecute();
     return bDone;
 }
 
-BOOL ModulWindow::BasicStepOver()
+sal_Bool ModulWindow::BasicStepOver()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     aStatus.nBasicFlags = SbDEBUG_STEPINTO | SbDEBUG_STEPOVER;
-    BOOL bDone = BasicExecute();
+    sal_Bool bDone = BasicExecute();
     return bDone;
 }
 
 
-BOOL ModulWindow::BasicStepInto()
+sal_Bool ModulWindow::BasicStepInto()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
 
     aStatus.nBasicFlags = SbDEBUG_STEPINTO;
-    BOOL bDone = BasicExecute();
+    sal_Bool bDone = BasicExecute();
     return bDone;
 }
 
-BOOL ModulWindow::BasicStepOut()
+sal_Bool ModulWindow::BasicStepOut()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
 
     aStatus.nBasicFlags = SbDEBUG_STEPOUT;
-    BOOL bDone = BasicExecute();
+    sal_Bool bDone = BasicExecute();
     return bDone;
 }
 
@@ -439,13 +434,13 @@ void ModulWindow::BasicStop()
     DBG_CHKTHIS( ModulWindow, 0 );
 
     GetBasic()->Stop();
-    aStatus.bIsRunning = FALSE;
+    aStatus.bIsRunning = sal_False;
 }
 
-BOOL ModulWindow::LoadBasic()
+sal_Bool ModulWindow::LoadBasic()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
-    BOOL bDone = FALSE;
+    sal_Bool bDone = sal_False;
 
     Reference< lang::XMultiServiceFactory > xMSF( ::comphelper::getProcessServiceFactory() );
     Reference < XFilePicker > xFP;
@@ -460,8 +455,6 @@ BOOL ModulWindow::LoadBasic()
     if ( aCurPath.Len() )
         xFP->setDisplayDirectory ( aCurPath );
 
-    //xFP->setTitle( String( IDEResId( RID_STR_OPEN ) ) );
-
     Reference< XFilterManager > xFltMgr(xFP, UNO_QUERY);
     xFltMgr->appendFilter( String( RTL_CONSTASCII_USTRINGPARAM( "BASIC" ) ), String( RTL_CONSTASCII_USTRINGPARAM( "*.bas" ) ) );
     xFltMgr->appendFilter( String( IDEResId( RID_STR_FILTER_ALLFILES ) ), String( RTL_CONSTASCII_USTRINGPARAM( FILTERMASK_ALL ) ) );
@@ -471,25 +464,25 @@ BOOL ModulWindow::LoadBasic()
     {
         Sequence< ::rtl::OUString > aPaths = xFP->getFiles();
         aCurPath = aPaths[0];
-        SfxMedium aMedium( aCurPath, STREAM_READ | STREAM_SHARE_DENYWRITE | STREAM_NOCREATE, TRUE );
+        SfxMedium aMedium( aCurPath, STREAM_READ | STREAM_SHARE_DENYWRITE | STREAM_NOCREATE, sal_True );
         SvStream* pStream = aMedium.GetInStream();
         if ( pStream )
         {
             AssertValidEditEngine();
-            ULONG nLines = CalcLineCount( *pStream );
+            sal_uLong nLines = CalcLineCount( *pStream );
             // nLines*4: ReadText/Formatting/Highlighting/Formatting
             GetEditorWindow().CreateProgress( String( IDEResId( RID_STR_GENERATESOURCE ) ), nLines*4 );
-            GetEditEngine()->SetUpdateMode( FALSE );
+            GetEditEngine()->SetUpdateMode( sal_False );
             GetEditView()->Read( *pStream );
-            GetEditEngine()->SetUpdateMode( TRUE );
-            GetEditorWindow().Update();	// Es wurde bei UpdateMode = TRUE nur Invalidiert
+            GetEditEngine()->SetUpdateMode( sal_True );
+            GetEditorWindow().Update();	// Es wurde bei UpdateMode = sal_True nur Invalidiert
             GetEditorWindow().ForceSyntaxTimeout();
             GetEditorWindow().DestroyProgress();
-            ULONG nError = aMedium.GetError();
+            sal_uLong nError = aMedium.GetError();
             if ( nError )
                 ErrorHandler::HandleError( nError );
             else
-                bDone = TRUE;
+                bDone = sal_True;
         }
         else
             ErrorBox( this, WB_OK | WB_DEF_OK, String( IDEResId( RID_STR_COULDNTREAD ) ) ).Execute();
@@ -498,10 +491,10 @@ BOOL ModulWindow::LoadBasic()
 }
 
 
-BOOL ModulWindow::SaveBasicSource()
+sal_Bool ModulWindow::SaveBasicSource()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
-    BOOL bDone = FALSE;
+    sal_Bool bDone = sal_False;
 
     Reference< lang::XMultiServiceFactory > xMSF( ::comphelper::getProcessServiceFactory() );
     Reference < XFilePicker > xFP;
@@ -522,8 +515,6 @@ BOOL ModulWindow::SaveBasicSource()
     if ( aCurPath.Len() )
         xFP->setDisplayDirectory ( aCurPath );
 
-    //xFP->setTitle( String( IDEResId( RID_STR_SAVE ) ) );
-
     Reference< XFilterManager > xFltMgr(xFP, UNO_QUERY);
     xFltMgr->appendFilter( String( RTL_CONSTASCII_USTRINGPARAM( "BASIC" ) ), String( RTL_CONSTASCII_USTRINGPARAM( "*.bas" ) ) );
     xFltMgr->appendFilter( String( IDEResId( RID_STR_FILTER_ALLFILES ) ), String( RTL_CONSTASCII_USTRINGPARAM( FILTERMASK_ALL ) ) );
@@ -533,7 +524,7 @@ BOOL ModulWindow::SaveBasicSource()
     {
         Sequence< ::rtl::OUString > aPaths = xFP->getFiles();
         aCurPath = aPaths[0];
-        SfxMedium aMedium( aCurPath, STREAM_WRITE | STREAM_SHARE_DENYWRITE | STREAM_TRUNC, TRUE, FALSE );
+        SfxMedium aMedium( aCurPath, STREAM_WRITE | STREAM_SHARE_DENYWRITE | STREAM_TRUNC, sal_True, sal_False );
         SvStream* pStream = aMedium.GetOutStream();
         if ( pStream )
         {
@@ -542,11 +533,11 @@ BOOL ModulWindow::SaveBasicSource()
             GetEditEngine()->Write( *pStream );
             aMedium.Commit();
             LeaveWait();
-            ULONG nError = aMedium.GetError();
+            sal_uLong nError = aMedium.GetError();
             if ( nError )
                 ErrorHandler::HandleError( nError );
             else
-                bDone = TRUE;
+                bDone = sal_True;
         }
         else
             ErrorBox( this, WB_OK | WB_DEF_OK, String( IDEResId( RID_STR_COULDNTWRITE) ) ).Execute();
@@ -555,21 +546,21 @@ BOOL ModulWindow::SaveBasicSource()
     return bDone;
 }
 
-BOOL implImportDialog( Window* pWin, const String& rCurPath, const ScriptDocument& rDocument, const String& aLibName ); 
+sal_Bool implImportDialog( Window* pWin, const String& rCurPath, const ScriptDocument& rDocument, const String& aLibName ); 
 
-BOOL ModulWindow::ImportDialog()
+sal_Bool ModulWindow::ImportDialog()
 {
     const ScriptDocument& rDocument = GetDocument();
     String aLibName = GetLibName();
-    BOOL bRet = implImportDialog( this, aCurPath, rDocument, aLibName );
+    sal_Bool bRet = implImportDialog( this, aCurPath, rDocument, aLibName );
     return bRet;
 }
 
-BOOL ModulWindow::ToggleBreakPoint( ULONG nLine )
+sal_Bool ModulWindow::ToggleBreakPoint( sal_uLong nLine )
 {
     DBG_ASSERT( XModule().Is(), "Kein Modul!" );
 
-    BOOL bNewBreakPoint = FALSE;
+    sal_Bool bNewBreakPoint = sal_False;
 
     if ( XModule().Is() )
     {
@@ -577,24 +568,24 @@ BOOL ModulWindow::ToggleBreakPoint( ULONG nLine )
         if ( aStatus.bError )
         {
             Sound::Beep();
-            return FALSE;
+            return sal_False;
         }
 
         BreakPoint* pBrk = GetBreakPoints().FindBreakPoint( nLine );
         if ( pBrk ) // entfernen
         {
-            xModule->ClearBP( (USHORT)nLine );
-            delete GetBreakPoints().Remove( pBrk );
+            xModule->ClearBP( (sal_uInt16)nLine );
+            delete GetBreakPoints().remove( pBrk );
         }
         else // einen erzeugen
         {
-            if ( xModule->SetBP( (USHORT)nLine) )
+            if ( xModule->SetBP( (sal_uInt16)nLine) )
             {
                 GetBreakPoints().InsertSorted( new BreakPoint( nLine ) );
-                bNewBreakPoint = TRUE;
+                bNewBreakPoint = sal_True;
                 if ( StarBASIC::IsRunning() )
                 {
-                    for ( USHORT nMethod = 0; nMethod < xModule->GetMethods()->Count(); nMethod++ )
+                    for ( sal_uInt16 nMethod = 0; nMethod < xModule->GetMethods()->Count(); nMethod++ )
                     {
                         SbMethod* pMethod = (SbMethod*)xModule->GetMethods()->Get( nMethod );
                         DBG_ASSERT( pMethod, "Methode nicht gefunden! (NULL)" );
@@ -620,14 +611,14 @@ void ModulWindow::UpdateBreakPoint( const BreakPoint& rBrk )
         CheckCompileBasic();
 
         if ( rBrk.bEnabled )
-            xModule->SetBP( (USHORT)rBrk.nLine );
+            xModule->SetBP( (sal_uInt16)rBrk.nLine );
         else
-            xModule->ClearBP( (USHORT)rBrk.nLine );
+            xModule->ClearBP( (sal_uInt16)rBrk.nLine );
     }
 }
 
 
-BOOL ModulWindow::BasicToggleBreakPoint()
+sal_Bool ModulWindow::BasicToggleBreakPoint()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     AssertValidEditEngine();
@@ -636,12 +627,12 @@ BOOL ModulWindow::BasicToggleBreakPoint()
     aSel.GetStart().GetPara()++;	// Basic-Zeilen beginnen bei 1!
     aSel.GetEnd().GetPara()++;
 
-    BOOL bNewBreakPoint = FALSE;
+    sal_Bool bNewBreakPoint = sal_False;
 
-    for ( ULONG nLine = aSel.GetStart().GetPara(); nLine <= aSel.GetEnd().GetPara(); nLine++ )
+    for ( sal_uLong nLine = aSel.GetStart().GetPara(); nLine <= aSel.GetEnd().GetPara(); nLine++ )
     {
         if ( ToggleBreakPoint( nLine ) )
-            bNewBreakPoint = TRUE;
+            bNewBreakPoint = sal_True;
     }
 
     aXEditorWindow.GetBrkWindow().Invalidate();
@@ -660,12 +651,12 @@ void ModulWindow::BasicToggleBreakPointEnabled()
         TextSelection aSel = pView->GetSelection();
         BreakPointList& rList = GetBreakPoints();
 
-        for ( ULONG nLine = ++aSel.GetStart().GetPara(), nEnd = ++aSel.GetEnd().GetPara(); nLine <= nEnd; ++nLine )
+        for ( sal_uLong nLine = ++aSel.GetStart().GetPara(), nEnd = ++aSel.GetEnd().GetPara(); nLine <= nEnd; ++nLine )
         {
             BreakPoint* pBrk = rList.FindBreakPoint( nLine );
             if ( pBrk )
             {
-                pBrk->bEnabled = pBrk->bEnabled ? FALSE : TRUE;
+                pBrk->bEnabled = pBrk->bEnabled ? sal_False : sal_True;
                 UpdateBreakPoint( *pBrk );
             }
         }
@@ -693,9 +684,9 @@ IMPL_LINK( ModulWindow, BasicErrorHdl, StarBASIC *, pBasic )
     //	FALSE:	Abbrechen
     //	TRUE:	Weiter....
     String aErrorText( pBasic->GetErrorText() );
-    USHORT nErrorLine = pBasic->GetLine() - 1;
-    USHORT nErrCol1 = pBasic->GetCol1();
-    USHORT nErrCol2 = pBasic->GetCol2();
+    sal_uInt16 nErrorLine = pBasic->GetLine() - 1;
+    sal_uInt16 nErrCol1 = pBasic->GetCol1();
+    sal_uInt16 nErrCol2 = pBasic->GetCol2();
     if ( nErrCol2 != 0xFFFF )
         nErrCol2++;
 
@@ -716,11 +707,9 @@ IMPL_LINK( ModulWindow, BasicErrorHdl, StarBASIC *, pBasic )
     }
     // Wenn anderes Basic, dan sollte die IDE versuchen, da richtige
     // Modul anzuzeigen...
-    BOOL bMarkError = ( pBasic == GetBasic() ) ? TRUE : FALSE;
+    sal_Bool bMarkError = ( pBasic == GetBasic() ) ? sal_True : sal_False;
     if ( bMarkError )
-        aXEditorWindow.GetBrkWindow().SetMarkerPos( nErrorLine, TRUE );
-//	ErrorBox( this, WB_OK | WB_DEF_OK, String( aErrorTextPrefix + aErrorText ) ).Execute();
-//	ErrorHandler::HandleError( pBasic->GetErrorCode() );
+        aXEditorWindow.GetBrkWindow().SetMarkerPos( nErrorLine, sal_True );
 
     // #i47002#
     Reference< awt::XWindow > xWindow = VCLUnoHelper::GetInterface( this );
@@ -730,28 +719,25 @@ IMPL_LINK( ModulWindow, BasicErrorHdl, StarBASIC *, pBasic )
     // #i47002#
     Window* pWindow = VCLUnoHelper::GetWindow( xWindow );
     if ( !pWindow )
-        return FALSE;
+        return sal_False;
 
     if ( bMarkError )
         aXEditorWindow.GetBrkWindow().SetMarkerPos( MARKER_NOMARKER );
-    return FALSE;
+    return sal_False;
 }
 
-long __EXPORT ModulWindow::BasicBreakHdl( StarBASIC* pBasic )
+long ModulWindow::BasicBreakHdl( StarBASIC* pBasic )
 {
     DBG_CHKTHIS( ModulWindow, 0 );
-    // Ein GoOnTop aktiviert da Fenster, das veraendert aber den Context fuer
-    // das Programm!
-//	GoOnTop();
 
     // #i69280 Required in Window despite normal usage in next command!
     (void)pBasic;
 
-    // ReturnWert: USHORT => siehe SB-Debug-Flags
-    USHORT nErrorLine = pBasic->GetLine();
+    // ReturnWert: sal_uInt16 => siehe SB-Debug-Flags
+    sal_uInt16 nErrorLine = pBasic->GetLine();
 
     // Gibt es hier einen BreakPoint?
-    BreakPoint* pBrk = GetBreakPoints().FindBreakPoint( nErrorLine );    
+    BreakPoint* pBrk = GetBreakPoints().FindBreakPoint( nErrorLine );
     if ( pBrk )
     {
         pBrk->nHitCount++;
@@ -768,8 +754,8 @@ long __EXPORT ModulWindow::BasicBreakHdl( StarBASIC* pBasic )
     pLayout->GetWatchWindow().UpdateWatches();
     pLayout->GetStackWindow().UpdateCalls();
 
-    aStatus.bIsInReschedule = TRUE;
-    aStatus.bIsRunning = TRUE;
+    aStatus.bIsInReschedule = sal_True;
+    aStatus.bIsRunning = sal_True;
 
     AddStatus( BASWIN_INRESCHEDULE );
 
@@ -778,7 +764,7 @@ long __EXPORT ModulWindow::BasicBreakHdl( StarBASIC* pBasic )
     while( aStatus.bIsRunning )
         Application::Yield();
 
-    aStatus.bIsInReschedule = FALSE;
+    aStatus.bIsInReschedule = sal_False;
     aXEditorWindow.GetBrkWindow().SetMarkerPos( MARKER_NOMARKER );
 
     ClearStatus( BASWIN_INRESCHEDULE );
@@ -790,22 +776,20 @@ void ModulWindow::BasicAddWatch()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     String aWatchStr;
-    BOOL bInserted = FALSE;
+    sal_Bool bInserted = sal_False;
     AssertValidEditEngine();
-    BOOL bAdd = TRUE;
+    sal_Bool bAdd = sal_True;
     if ( !GetEditView()->HasSelection() )
     {
-//		bAdd = GetEditView()->SelectCurrentWord();
         TextPaM aWordStart;
         String aWord = GetEditEngine()->GetWord( GetEditView()->GetSelection().GetEnd(), &aWordStart );
         if ( aWord.Len() )
         {
             TextSelection aSel( aWordStart );
-            USHORT& rIndex = aSel.GetEnd().GetIndex();
+            sal_uInt16& rIndex = aSel.GetEnd().GetIndex();
             rIndex = rIndex + aWord.Len();
-            // aSel.GetEnd().GetIndex() += sal::static_int_cast<int>( aWord.Len() );
             GetEditView()->SetSelection( aSel );
-            bAdd = TRUE;
+            bAdd = sal_True;
         }
     }
     if ( bAdd )
@@ -816,7 +800,7 @@ void ModulWindow::BasicAddWatch()
             aWatchStr = GetEditView()->GetSelected();
             pLayout->GetWatchWindow().AddWatch( aWatchStr );
             pLayout->GetWatchWindow().UpdateWatches();
-            bInserted = TRUE;
+            bInserted = sal_True;
         }
     }
 
@@ -829,7 +813,7 @@ void ModulWindow::BasicAddWatch()
 void ModulWindow::BasicRemoveWatch()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
-    BOOL bRemoved = pLayout->GetWatchWindow().RemoveSelectedWatch();
+    sal_Bool bRemoved = pLayout->GetWatchWindow().RemoveSelectedWatch();
 
     if ( !bRemoved )
         Sound::Beep();
@@ -847,7 +831,7 @@ void ModulWindow::EditMacro( const String& rMacroName )
 
         if ( !aStatus.bError )
         {
-            USHORT nStart, nEnd;
+            sal_uInt16 nStart, nEnd;
             SbMethod* pMethod = (SbMethod*)xModule->Find( rMacroName, SbxCLASS_METHOD );
             if ( pMethod )
             {
@@ -870,7 +854,7 @@ void ModulWindow::EditMacro( const String& rMacroName )
                     long nNewStartY = nStart * pView->GetTextEngine()->GetCharHeight();
                     nNewStartY = Min( nNewStartY, nMaxY );
                     pView->Scroll( 0, -(nNewStartY-nOldStartY) );
-                    pView->ShowCursor( FALSE, TRUE );
+                    pView->ShowCursor( sal_False, sal_True );
                     GetEditVScrollBar().SetThumbPos( pView->GetStartDocPos().Y() );
                 }
                 pView->SetSelection( aSel );
@@ -882,33 +866,30 @@ void ModulWindow::EditMacro( const String& rMacroName )
 }
 
 
-void __EXPORT ModulWindow::StoreData()
+void ModulWindow::StoreData()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     // StoreData wird gerufen, wenn der BasicManager zerstoert oder
     // dieses Fenster beendet wird.
     // => Keine Unterbrechungen erwuenscht!
     // Und bei SAVE, wenn AppBasic...
-    GetEditorWindow().SetSourceInBasic( TRUE );
-    // Nicht das Modify loeschen, sonst wird das Basic nicht gespeichert
-    // Es wird beim Speichern sowieso geloescht.
-//	xModule->SetModified( FALSE );
+    GetEditorWindow().SetSourceInBasic( sal_True );
 }
 
-BOOL __EXPORT ModulWindow::CanClose()
+sal_Bool ModulWindow::CanClose()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
-    return TRUE;
+    return sal_True;
 }
 
 
-BOOL __EXPORT ModulWindow::AllowUndo()
+sal_Bool ModulWindow::AllowUndo()
 {
     return GetEditorWindow().CanModify();
 }
 
 
-void __EXPORT ModulWindow::UpdateData()
+void ModulWindow::UpdateData()
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     DBG_ASSERT( XModule().Is(), "Kein Modul!" );
@@ -925,7 +906,7 @@ void __EXPORT ModulWindow::UpdateData()
             TextSelection aSel = GetEditView()->GetSelection();
             setTextEngineText( GetEditEngine(), xModule->GetSource32() );
             GetEditView()->SetSelection( aSel );
-            GetEditEngine()->SetModified( FALSE );
+            GetEditEngine()->SetModified( sal_False );
             BasicIDE::MarkDocumentModified( GetDocument() );
         }
     }
@@ -952,44 +933,43 @@ sal_Int32 ModulWindow::FormatAndPrint( Printer* pPrinter, sal_Int32 nPrintPage )
     DBG_CHKTHIS( ModulWindow, 0 );
 
     AssertValidEditEngine();
-    
+
     MapMode eOldMapMode( pPrinter->GetMapMode() );
     Font aOldFont( pPrinter->GetFont() );
 
-//	Font aFont( GetEditEngine()->CreateFontFromItemSet( GetEditEngine()->GetEmptyItemSet() ) );
     Font aFont( GetEditEngine()->GetFont() );
     aFont.SetAlign( ALIGN_BOTTOM );
-    aFont.SetTransparent( TRUE );
+    aFont.SetTransparent( sal_True );
     aFont.SetSize( Size( 0, 360 ) );
     pPrinter->SetFont( aFont );
     pPrinter->SetMapMode( MAP_100TH_MM );
 
     String aTitle( CreateQualifiedName() );
 
-    USHORT nLineHeight = (USHORT) pPrinter->GetTextHeight(); // etwas mehr.
-    USHORT nParaSpace = 10;
+    sal_uInt16 nLineHeight = (sal_uInt16) pPrinter->GetTextHeight(); // etwas mehr.
+    sal_uInt16 nParaSpace = 10;
 
     Size aPaperSz = pPrinter->GetOutputSize();
     aPaperSz.Width() -= (LMARGPRN+RMARGPRN);
     aPaperSz.Height() -= (TMARGPRN+BMARGPRN);
 
     // nLinepPage stimmt nicht, wenn Zeilen umgebrochen werden muessen...
-    USHORT nLinespPage = (USHORT) (aPaperSz.Height()/nLineHeight);
-    USHORT nCharspLine = (USHORT) (aPaperSz.Width() / pPrinter->GetTextWidth( 'X' ) );
-    ULONG nParas = GetEditEngine()->GetParagraphCount();
+    sal_uInt16 nLinespPage = (sal_uInt16) (aPaperSz.Height()/nLineHeight);
+    sal_uInt16 nCharspLine = (sal_uInt16) (aPaperSz.Width() / pPrinter->GetTextWidth( 'X' ) );
+    sal_uLong nParas = GetEditEngine()->GetParagraphCount();
 
-    USHORT nPages = (USHORT) (nParas/nLinespPage+1 );
-    USHORT nCurPage = 1;
+    sal_uInt16 nPages = (sal_uInt16) (nParas/nLinespPage+1 );
+    sal_uInt16 nCurPage = 1;
 
     // Header drucken...
     lcl_PrintHeader( pPrinter, nPages, nCurPage, aTitle, nPrintPage == 0 );
     Point aPos( LMARGPRN, TMARGPRN );
-    for ( ULONG nPara = 0; nPara < nParas; nPara++ )
+    for ( sal_uLong nPara = 0; nPara < nParas; nPara++ )
     {
         String aLine( GetEditEngine()->GetText( nPara ) );
         lcl_ConvertTabsToSpaces( aLine );
-        USHORT nLines = aLine.Len()/nCharspLine+1;
-        for ( USHORT nLine = 0; nLine < nLines; nLine++ )
+        sal_uInt16 nLines = aLine.Len()/nCharspLine+1;
+        for ( sal_uInt16 nLine = 0; nLine < nLines; nLine++ )
         {
             String aTmpLine( aLine, nLine*nCharspLine, nCharspLine );
             aPos.Y() += nLineHeight;
@@ -1007,16 +987,16 @@ sal_Int32 ModulWindow::FormatAndPrint( Printer* pPrinter, sal_Int32 nPrintPage )
 
     pPrinter->SetFont( aOldFont );
     pPrinter->SetMapMode( eOldMapMode );
-    
+
     return sal_Int32(nCurPage);
 }
 
 
-void __EXPORT ModulWindow::ExecuteCommand( SfxRequest& rReq )
+void ModulWindow::ExecuteCommand( SfxRequest& rReq )
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     AssertValidEditEngine();
-    USHORT nSlot = rReq.GetSlot();
+    sal_uInt16 nSlot = rReq.GetSlot();
     switch ( nSlot )
     {
         case SID_BASICRUN:
@@ -1127,11 +1107,11 @@ void __EXPORT ModulWindow::ExecuteCommand( SfxRequest& rReq )
 
 
 
-void __EXPORT ModulWindow::GetState( SfxItemSet &rSet )
+void ModulWindow::GetState( SfxItemSet &rSet )
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     SfxWhichIter aIter(rSet);
-    for ( USHORT nWh = aIter.FirstWhich(); 0 != nWh; nWh = aIter.NextWhich() )
+    for ( sal_uInt16 nWh = aIter.FirstWhich(); 0 != nWh; nWh = aIter.NextWhich() )
     {
         switch ( nWh )
         {
@@ -1193,7 +1173,7 @@ void __EXPORT ModulWindow::GetState( SfxItemSet &rSet )
 }
 
 
-void __EXPORT ModulWindow::DoScroll( ScrollBar* pCurScrollBar )
+void ModulWindow::DoScroll( ScrollBar* pCurScrollBar )
 {
     DBG_CHKTHIS( ModulWindow, 0 );
     if ( ( pCurScrollBar == GetHScrollBar() ) && GetEditView() )
@@ -1202,21 +1182,21 @@ void __EXPORT ModulWindow::DoScroll( ScrollBar* pCurScrollBar )
         // VisArea verwenden:
         long nDiff = GetEditView()->GetStartDocPos().X() - pCurScrollBar->GetThumbPos();
         GetEditView()->Scroll( nDiff, 0 );
-        GetEditView()->ShowCursor( FALSE, TRUE );
+        GetEditView()->ShowCursor( sal_False, sal_True );
         pCurScrollBar->SetThumbPos( GetEditView()->GetStartDocPos().X() );
 
     }
 }
 
 
-BOOL __EXPORT ModulWindow::IsModified()
+sal_Bool ModulWindow::IsModified()
 {
-    return GetEditEngine() ? GetEditEngine()->IsModified() : FALSE;
+    return GetEditEngine() ? GetEditEngine()->IsModified() : sal_False;
 }
 
 
 
-void __EXPORT ModulWindow::GoOnTop()
+void ModulWindow::GoOnTop()
 {
     IDE_DLL()->GetShell()->GetViewFrame()->ToTop();
 }
@@ -1231,7 +1211,7 @@ String ModulWindow::GetSbModuleName()
 
 
 
-String __EXPORT ModulWindow::GetTitle()
+String ModulWindow::GetTitle()
 {
     return GetSbModuleName();
 }
@@ -1240,13 +1220,11 @@ String __EXPORT ModulWindow::GetTitle()
 
 void ModulWindow::FrameWindowMoved()
 {
-//	if ( GetEditEngine() && GetEditEngine()->IsInSelectionMode() )
-//		GetEditEngine()->StopSelectionMode();
 }
 
 
 
-void ModulWindow::ShowCursor( BOOL bOn )
+void ModulWindow::ShowCursor( sal_Bool bOn )
 {
     if ( GetEditEngine() )
     {
@@ -1262,7 +1240,7 @@ void ModulWindow::ShowCursor( BOOL bOn )
 }
 
 
-Window* __EXPORT ModulWindow::GetLayoutWindow()
+Window* ModulWindow::GetLayoutWindow()
 {
     return pLayout;
 }
@@ -1279,7 +1257,7 @@ void ModulWindow::Deactivating()
         GetEditView()->EraseVirtualDevice();
 }
 
-USHORT ModulWindow::StartSearchAndReplace( const SvxSearchItem& rSearchItem, BOOL bFromStart )
+sal_uInt16 ModulWindow::StartSearchAndReplace( const SvxSearchItem& rSearchItem, sal_Bool bFromStart )
 {
     // Mann koennte fuer das blinde Alle-Ersetzen auch auf
     // Syntaxhighlighting/Formatierung verzichten...
@@ -1295,8 +1273,8 @@ USHORT ModulWindow::StartSearchAndReplace( const SvxSearchItem& rSearchItem, BOO
             pView->SetSelection( TextSelection( TextPaM( 0xFFFFFFFF, 0xFFFF ), TextPaM( 0xFFFFFFFF, 0xFFFF ) ) );
     }
 
-    BOOL bForward = !rSearchItem.GetBackward();
-    USHORT nFound = 0;
+    sal_Bool bForward = !rSearchItem.GetBackward();
+    sal_uInt16 nFound = 0;
     if ( ( rSearchItem.GetCommand() == SVX_SEARCHCMD_FIND ) ||
          ( rSearchItem.GetCommand() == SVX_SEARCHCMD_FIND_ALL ) )
     {
@@ -1307,7 +1285,7 @@ USHORT ModulWindow::StartSearchAndReplace( const SvxSearchItem& rSearchItem, BOO
     {
         if ( !IsReadOnly() )
         {
-            BOOL bAll = rSearchItem.GetCommand() == SVX_SEARCHCMD_REPLACE_ALL;
+            sal_Bool bAll = rSearchItem.GetCommand() == SVX_SEARCHCMD_REPLACE_ALL;
             nFound = pView->Replace( rSearchItem.GetSearchOptions() , bAll , bForward );
         }
     }
@@ -1318,16 +1296,16 @@ USHORT ModulWindow::StartSearchAndReplace( const SvxSearchItem& rSearchItem, BOO
     return nFound;
 }
 
-SfxUndoManager* __EXPORT ModulWindow::GetUndoManager()
+::svl::IUndoManager* ModulWindow::GetUndoManager()
 {
     if ( GetEditEngine() )
         return &GetEditEngine()->GetUndoManager();
     return NULL;
 }
 
-USHORT __EXPORT ModulWindow::GetSearchOptions()
+sal_uInt16 ModulWindow::GetSearchOptions()
 {
-    USHORT nOptions = SEARCH_OPTIONS_SEARCH |
+    sal_uInt16 nOptions = SEARCH_OPTIONS_SEARCH |
                       SEARCH_OPTIONS_WHOLE_WORDS |
                       SEARCH_OPTIONS_BACKWARDS |
                       SEARCH_OPTIONS_REG_EXP |
@@ -1344,17 +1322,17 @@ USHORT __EXPORT ModulWindow::GetSearchOptions()
     return nOptions;
 }
 
-void __EXPORT ModulWindow::BasicStarted()
+void ModulWindow::BasicStarted()
 {
     if ( XModule().Is() )
     {
-        aStatus.bIsRunning = TRUE;
+        aStatus.bIsRunning = sal_True;
         BreakPointList& rList = GetBreakPoints();
-        if ( rList.Count() )
+        if ( rList.size() )
         {
             rList.ResetHitCount();
             rList.SetBreakPointsInBasic( xModule );
-            for ( USHORT nMethod = 0; nMethod < xModule->GetMethods()->Count(); nMethod++ )
+            for ( sal_uInt16 nMethod = 0; nMethod < xModule->GetMethods()->Count(); nMethod++ )
             {
                 SbMethod* pMethod = (SbMethod*)xModule->GetMethods()->Get( nMethod );
                 DBG_ASSERT( pMethod, "Methode nicht gefunden! (NULL)" );
@@ -1364,9 +1342,9 @@ void __EXPORT ModulWindow::BasicStarted()
     }
 }
 
-void __EXPORT ModulWindow::BasicStopped()
+void ModulWindow::BasicStopped()
 {
-    aStatus.bIsRunning = FALSE;
+    aStatus.bIsRunning = sal_False;
     GetBreakPointWindow().SetMarkerPos( MARKER_NOMARKER );
 }
 
@@ -1395,7 +1373,7 @@ BasicEntryDescriptor ModulWindow::CreateEntryDescriptor()
                     }
                 }
                 break;
-            }    
+            }
             case script::ModuleType::FORM:
                 aLibSubName = String( IDEResId( RID_STR_USERFORMS ) );
                 break;
@@ -1410,15 +1388,15 @@ BasicEntryDescriptor ModulWindow::CreateEntryDescriptor()
     return BasicEntryDescriptor( aDocument, eLocation, aLibName, aLibSubName, aModName, OBJ_TYPE_MODULE );
 }
 
-void ModulWindow::SetReadOnly( BOOL b )
+void ModulWindow::SetReadOnly( sal_Bool b )
 {
     if ( GetEditView() )
         GetEditView()->SetReadOnly( b );
 }
 
-BOOL ModulWindow::IsReadOnly()
+sal_Bool ModulWindow::IsReadOnly()
 {
-    BOOL bReadOnly = FALSE;
+    sal_Bool bReadOnly = sal_False;
 
     if ( GetEditView() )
         bReadOnly = GetEditView()->IsReadOnly();
@@ -1426,9 +1404,9 @@ BOOL ModulWindow::IsReadOnly()
     return bReadOnly;
 }
 
-BOOL ModulWindow::IsPasteAllowed()
+sal_Bool ModulWindow::IsPasteAllowed()
 {
-    BOOL bPaste = FALSE;
+    sal_Bool bPaste = sal_False;
 
     // get clipboard
     Reference< datatransfer::clipboard::XClipboard > xClipboard = GetClipboard();
@@ -1444,7 +1422,7 @@ BOOL ModulWindow::IsPasteAllowed()
             SotExchange::GetFormatDataFlavor( SOT_FORMAT_STRING, aFlavor );
             if ( xTransf->isDataFlavorSupported( aFlavor ) )
             {
-                bPaste = TRUE;
+                bPaste = sal_True;
             }
         }
     }
@@ -1458,11 +1436,10 @@ ModulWindowLayout::ModulWindowLayout( Window* pParent ) :
     aHSplitter( this, WinBits( WB_HSCROLL ) ),
     aWatchWindow( this ),
     aStackWindow( this ),
-    bVSplitted(FALSE),
-    bHSplitted(FALSE),
+    bVSplitted(sal_False),
+    bHSplitted(sal_False),
     m_pModulWindow(0),
-    m_aImagesNormal(IDEResId(RID_IMGLST_LAYOUT)),
-    m_aImagesHighContrast(IDEResId(RID_IMGLST_LAYOUT_HC))
+    m_aImagesNormal(IDEResId(RID_IMGLST_LAYOUT))
 {
     SetBackground(GetSettings().GetStyleSettings().GetWindowColor());
 
@@ -1509,14 +1486,13 @@ ModulWindowLayout::~ModulWindowLayout()
     m_aColorConfig.RemoveListener(this);
 }
 
-void __EXPORT ModulWindowLayout::Resize()
+void ModulWindowLayout::Resize()
 {
     // ScrollBars, etc. passiert in BasicIDEShell:Adjust...
     ArrangeWindows();
-//	Invalidate();
 }
 
-void __EXPORT ModulWindowLayout::Paint( const Rectangle& )
+void ModulWindowLayout::Paint( const Rectangle& )
 {
     DrawText( Point(), String( IDEResId( RID_STR_NOMODULE ) ) );
 }
@@ -1596,15 +1572,15 @@ void ModulWindowLayout::ArrangeWindows()
 IMPL_LINK( ModulWindowLayout, SplitHdl, Splitter *, pSplitter )
 {
     if ( pSplitter == &aVSplitter )
-        bVSplitted = TRUE;
+        bVSplitted = sal_True;
     else
-        bHSplitted = TRUE;
+        bHSplitted = sal_True;
 
     ArrangeWindows();
     return 0;
 }
 
-BOOL ModulWindowLayout::IsToBeDocked( DockingWindow* pDockingWindow, const Point& rPos, Rectangle& rRect )
+sal_Bool ModulWindowLayout::IsToBeDocked( DockingWindow* pDockingWindow, const Point& rPos, Rectangle& rRect )
 {
     // prueffen, ob als Dock oder als Child:
     // TRUE:	Floating
@@ -1622,7 +1598,7 @@ BOOL ModulWindowLayout::IsToBeDocked( DockingWindow* pDockingWindow, const Point
             {
                 rRect.SetSize( Size( nHSplitPos, aSz.Height() - nVSplitPos ) );
                 rRect.SetPos( OutputToScreenPixel( Point( 0, nVSplitPos ) ) );
-                return TRUE;
+                return sal_True;
             }
         }
         if ( pDockingWindow == &aStackWindow )
@@ -1631,11 +1607,11 @@ BOOL ModulWindowLayout::IsToBeDocked( DockingWindow* pDockingWindow, const Point
             {
                 rRect.SetSize( Size( aSz.Width() - nHSplitPos, aSz.Height() - nVSplitPos ) );
                 rRect.SetPos( OutputToScreenPixel( Point( nHSplitPos, nVSplitPos ) ) );
-                return TRUE;
+                return sal_True;
             }
         }
     }
-    return FALSE;
+    return sal_False;
 }
 
 void ModulWindowLayout::DockaWindow( DockingWindow* pDockingWindow )
@@ -1650,9 +1626,9 @@ void ModulWindowLayout::DockaWindow( DockingWindow* pDockingWindow )
         // evtl. Sonderbehandlung...
         ArrangeWindows();
     }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 0
     else
-        DBG_ERROR( "Wer will sich denn hier andocken ?" );
+        OSL_FAIL( "Wer will sich denn hier andocken ?" );
 #endif
 }
 
@@ -1744,16 +1720,15 @@ void ModulWindowLayout::updateSyntaxHighlighting()
     if (m_pModulWindow != 0)
     {
         EditorWindow & rEditor = m_pModulWindow->GetEditorWindow();
-        ULONG nCount = rEditor.GetEditEngine()->GetParagraphCount();
-        for (ULONG i = 0; i < nCount; ++i)
+        sal_uLong nCount = rEditor.GetEditEngine()->GetParagraphCount();
+        for (sal_uLong i = 0; i < nCount; ++i)
             rEditor.DoDelayedSyntaxHighlight(i);
     }
 }
 
-Image ModulWindowLayout::getImage(USHORT nId, bool bHighContrastMode) const
+Image ModulWindowLayout::getImage(sal_uInt16 nId) const
 {
-    return (bHighContrastMode ? m_aImagesHighContrast : m_aImagesNormal).
-        GetImage(nId);
+    return m_aImagesNormal.GetImage(nId);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
