@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -38,7 +38,7 @@
 #include "dlgedclip.hxx"
 #include <dlgeddef.hxx>
 #include "propbrw.hxx"
-#include <localizationmgr.hxx> 
+#include <localizationmgr.hxx>
 
 #include <basidesh.hxx>
 #include <iderdll.hxx>
@@ -72,12 +72,9 @@ using namespace ::com::sun::star::beans;
 using namespace	::com::sun::star::io;
 using ::rtl::OUString;
 
-static ::rtl::OUString aResourceResolverPropName =
-    ::rtl::OUString::createFromAscii( "ResourceResolver" );
-static ::rtl::OUString aDecorationPropName =
-    ::rtl::OUString::createFromAscii( "Decoration" );
-static ::rtl::OUString aTitlePropName =
-    ::rtl::OUString::createFromAscii( "Title" );
+static ::rtl::OUString aResourceResolverPropName( RTL_CONSTASCII_USTRINGPARAM( "ResourceResolver" ));
+static ::rtl::OUString aDecorationPropName( RTL_CONSTASCII_USTRINGPARAM( "Decoration" ));
+static ::rtl::OUString aTitlePropName( RTL_CONSTASCII_USTRINGPARAM( "Title" ));
 
 
 //============================================================================
@@ -86,14 +83,11 @@ static ::rtl::OUString aTitlePropName =
 
 TYPEINIT1( DlgEdHint, SfxHint );
 
-//----------------------------------------------------------------------------
-
 DlgEdHint::DlgEdHint( DlgEdHintKind eHint )
     :eHintKind( eHint )
 {
 }
 
-//----------------------------------------------------------------------------
 
 DlgEdHint::DlgEdHint( DlgEdHintKind eHint, DlgEdObj* pObj )
     :eHintKind( eHint )
@@ -101,7 +95,6 @@ DlgEdHint::DlgEdHint( DlgEdHintKind eHint, DlgEdObj* pObj )
 {
 }
 
-//----------------------------------------------------------------------------
 
 DlgEdHint::~DlgEdHint()
 {
@@ -137,7 +130,7 @@ void DlgEditor::ShowDialog()
             }
             catch( UnknownPropertyException& )
             {
-                DBG_ERROR( "DlgEditor::ShowDialog(): No ResourceResolver property" );
+                OSL_FAIL( "DlgEditor::ShowDialog(): No ResourceResolver property" );
             }
         }
 
@@ -172,37 +165,34 @@ void DlgEditor::ShowDialog()
         xComponent->dispose();
 }
 
-//----------------------------------------------------------------------------
 
-BOOL DlgEditor::UnmarkDialog()
+sal_Bool DlgEditor::UnmarkDialog()
 {
     SdrObject* 		pDlgObj = pDlgEdModel->GetPage(0)->GetObj(0);
     SdrPageView*    pPgView = pDlgEdView->GetSdrPageView();
 
-    BOOL bWasMarked = pDlgEdView->IsObjMarked( pDlgObj );
+    sal_Bool bWasMarked = pDlgEdView->IsObjMarked( pDlgObj );
 
     if( bWasMarked )
-        pDlgEdView->MarkObj( pDlgObj, pPgView, TRUE );
+        pDlgEdView->MarkObj( pDlgObj, pPgView, sal_True );
 
     return bWasMarked;
 }
 
-//----------------------------------------------------------------------------
 
-BOOL DlgEditor::RemarkDialog()
+sal_Bool DlgEditor::RemarkDialog()
 {
     SdrObject* 		pDlgObj = pDlgEdModel->GetPage(0)->GetObj(0);
     SdrPageView*    pPgView = pDlgEdView->GetSdrPageView();
 
-    BOOL bWasMarked = pDlgEdView->IsObjMarked( pDlgObj );
+    sal_Bool bWasMarked = pDlgEdView->IsObjMarked( pDlgObj );
 
     if( !bWasMarked )
-        pDlgEdView->MarkObj( pDlgObj, pPgView, FALSE );
+        pDlgEdView->MarkObj( pDlgObj, pPgView, sal_False );
 
     return bWasMarked;
 }
 
-//----------------------------------------------------------------------------
 
 DlgEditor::DlgEditor( const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel >& xModel )
     :pHScroll(NULL)
@@ -219,12 +209,12 @@ DlgEditor::DlgEditor( const ::com::sun::star::uno::Reference< ::com::sun::star::
     ,pFunc(NULL)
     ,eMode( DLGED_SELECT )
     ,eActObj( OBJ_DLG_PUSHBUTTON )
-    ,bFirstDraw(FALSE)
+    ,bFirstDraw(sal_False)
     ,aGridSize( 100, 100 )	// 100TH_MM
-    ,bGridVisible(FALSE)
-    ,bGridSnap(TRUE)
-    ,bCreateOK(TRUE)
-    ,bDialogModelChanged(FALSE)
+    ,bGridVisible(sal_False)
+    ,bGridSnap(sal_True)
+    ,bCreateOK(sal_True)
+    ,bDialogModelChanged(sal_False)
     ,mnPaintGuard(0)
     ,m_xDocument( xModel )
 {
@@ -244,14 +234,14 @@ DlgEditor::DlgEditor( const ::com::sun::star::uno::Reference< ::com::sun::star::
     pFunc = new DlgEdFuncSelect( this );
 
     // set clipboard data flavors
-    m_ClipboardDataFlavors[0].MimeType =				::rtl::OUString::createFromAscii("application/vnd.sun.xml.dialog");
-    m_ClipboardDataFlavors[0].HumanPresentableName =	::rtl::OUString::createFromAscii("Dialog 6.0");
-    m_ClipboardDataFlavors[0].DataType =				::getCppuType( (const Sequence< sal_Int8 >*) 0 );
+    m_ClipboardDataFlavors[0].MimeType =             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "application/vnd.sun.xml.dialog" ));
+    m_ClipboardDataFlavors[0].HumanPresentableName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Dialog 6.0" ));
+    m_ClipboardDataFlavors[0].DataType =             ::getCppuType( (const Sequence< sal_Int8 >*) 0 );
 
-    m_ClipboardDataFlavorsResource[0] =							m_ClipboardDataFlavors[0];
-    m_ClipboardDataFlavorsResource[1].MimeType =				::rtl::OUString::createFromAscii("application/vnd.sun.xml.dialogwithresource");
-    m_ClipboardDataFlavorsResource[1].HumanPresentableName =	::rtl::OUString::createFromAscii("Dialog 8.0");
-    m_ClipboardDataFlavorsResource[1].DataType =				::getCppuType( (const Sequence< sal_Int8 >*) 0 );
+    m_ClipboardDataFlavorsResource[0] =                      m_ClipboardDataFlavors[0];
+    m_ClipboardDataFlavorsResource[1].MimeType =             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "application/vnd.sun.xml.dialogwithresource" ));
+    m_ClipboardDataFlavorsResource[1].HumanPresentableName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Dialog 8.0" ));
+    m_ClipboardDataFlavorsResource[1].DataType =             ::getCppuType( (const Sequence< sal_Int8 >*) 0 );
 
     aPaintTimer.SetTimeout( 1 );
     aPaintTimer.SetTimeoutHdl( LINK( this, DlgEditor, PaintTimeout ) );
@@ -260,7 +250,6 @@ DlgEditor::DlgEditor( const ::com::sun::star::uno::Reference< ::com::sun::star::
     aMarkTimer.SetTimeoutHdl( LINK( this, DlgEditor, MarkTimeout ) );
 }
 
-//----------------------------------------------------------------------------
 
 DlgEditor::~DlgEditor()
 {
@@ -275,7 +264,6 @@ DlgEditor::~DlgEditor()
     delete pDlgEdModel;
 }
 
-//----------------------------------------------------------------------------
 
 Reference< awt::XControlContainer > DlgEditor::GetWindowControlContainer()
 {
@@ -284,7 +272,6 @@ Reference< awt::XControlContainer > DlgEditor::GetWindowControlContainer()
     return m_xControlContainer;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::SetWindow( Window* pWindow_ )
 {
@@ -292,24 +279,23 @@ void DlgEditor::SetWindow( Window* pWindow_ )
     pWindow_->SetMapMode( MapMode( MAP_100TH_MM ) );
     pDlgEdPage->SetSize( pWindow_->PixelToLogic( Size( DLGED_PAGE_WIDTH_MIN, DLGED_PAGE_HEIGHT_MIN ) ) );
 
-    pDlgEdView = new DlgEdView( pDlgEdModel, pWindow_, this ); 
+    pDlgEdView = new DlgEdView( pDlgEdModel, pWindow_, this );
     pDlgEdView->ShowSdrPage(pDlgEdView->GetModel()->GetPage(0));
-    pDlgEdView->SetLayerVisible( UniString::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "HiddenLayer" ) ), FALSE );
-    pDlgEdView->SetMoveSnapOnlyTopLeft( TRUE );
+    pDlgEdView->SetLayerVisible( UniString::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "HiddenLayer" ) ), sal_False );
+    pDlgEdView->SetMoveSnapOnlyTopLeft( sal_True );
     pDlgEdView->SetWorkArea( Rectangle( Point( 0, 0 ), pDlgEdPage->GetSize() ) );
 
     pDlgEdView->SetGridCoarse( aGridSize );
     pDlgEdView->SetSnapGridWidth(Fraction(aGridSize.Width(), 1), Fraction(aGridSize.Height(), 1));
     pDlgEdView->SetGridSnap( bGridSnap );
     pDlgEdView->SetGridVisible( bGridVisible );
-    pDlgEdView->SetDragStripes( FALSE );
+    pDlgEdView->SetDragStripes( sal_False );
 
-    pDlgEdView->SetDesignMode( TRUE );
+    pDlgEdView->SetDesignMode( sal_True );
 
     ::comphelper::disposeComponent( m_xControlContainer );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::SetScrollBars( ScrollBar* pHS, ScrollBar* pVS )
 {
@@ -319,7 +305,6 @@ void DlgEditor::SetScrollBars( ScrollBar* pHS, ScrollBar* pVS )
     InitScrollBars();
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::InitScrollBars()
 {
@@ -333,8 +318,8 @@ void DlgEditor::InitScrollBars()
 
     pHScroll->SetRange( Range( 0, aPgSize.Width()  ));
     pVScroll->SetRange( Range( 0, aPgSize.Height() ));
-    pHScroll->SetVisibleSize( (ULONG)aOutSize.Width() );
-    pVScroll->SetVisibleSize( (ULONG)aOutSize.Height() );
+    pHScroll->SetVisibleSize( (sal_uLong)aOutSize.Width() );
+    pVScroll->SetVisibleSize( (sal_uLong)aOutSize.Height() );
 
     pHScroll->SetLineSize( aOutSize.Width() / 10 );
     pVScroll->SetLineSize( aOutSize.Height() / 10 );
@@ -345,7 +330,6 @@ void DlgEditor::InitScrollBars()
     DoScroll( pVScroll );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::DoScroll( ScrollBar* )
 {
@@ -375,18 +359,15 @@ void DlgEditor::DoScroll( ScrollBar* )
     //	pWindow->SetBackground();
 
     // #i74769# children should be scrolled
-    pWindow->Scroll( -nX, -nY, SCROLL_CHILDREN); // SCROLL_NOCHILDREN );
+    pWindow->Scroll( -nX, -nY, SCROLL_CHILDREN);
     aMap.SetOrigin( Point( -aScrollPos.Width(), -aScrollPos.Height() ) );
     pWindow->SetMapMode( aMap );
     pWindow->Update();
 
-    // pWindow->SetBackground( aOldBackground );
-
     DlgEdHint aHint( DLGED_HINT_WINDOWSCROLLED );
     Broadcast( aHint );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::UpdateScrollBars()
 {
@@ -400,7 +381,6 @@ void DlgEditor::UpdateScrollBars()
         pVScroll->SetThumbPos( -aOrg.Y() );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::SetDialog( uno::Reference< container::XNameContainer > xUnoControlDialogModel )
 {
@@ -460,13 +440,13 @@ void DlgEditor::SetDialog( uno::Reference< container::XNameContainer > xUnoContr
             pDlgEdModel->GetPage(0)->InsertObject( pCtrlObj );
             pCtrlObj->SetRectFromProps();
             pCtrlObj->UpdateStep();
-            pCtrlObj->StartListening();           
+            pCtrlObj->StartListening();
         }
     }
 
-    bFirstDraw = TRUE;
+    bFirstDraw = sal_True;
 
-    pDlgEdModel->SetChanged( FALSE );
+    pDlgEdModel->SetChanged( sal_False );
 }
 
 void DlgEditor::ResetDialog( void )
@@ -474,26 +454,24 @@ void DlgEditor::ResetDialog( void )
     DlgEdForm* pOldDlgEdForm = pDlgEdForm;
     DlgEdPage* pPage = (DlgEdPage*)pDlgEdModel->GetPage(0);
     SdrPageView* pPgView = pDlgEdView->GetSdrPageView();
-    BOOL bWasMarked = pDlgEdView->IsObjMarked( pOldDlgEdForm );
+    sal_Bool bWasMarked = pDlgEdView->IsObjMarked( pOldDlgEdForm );
     pDlgEdView->UnmarkAll();
     pPage->Clear();
     pPage->SetDlgEdForm( NULL );
     SetDialog( m_xUnoControlDialogModel );
     if( bWasMarked )
-        pDlgEdView->MarkObj( pDlgEdForm, pPgView, FALSE );
+        pDlgEdView->MarkObj( pDlgEdForm, pPgView, sal_False );
 }
 
 
-//----------------------------------------------------------------------------
-
 Reference< util::XNumberFormatsSupplier > const & DlgEditor::GetNumberFormatsSupplier()
 {
     if ( !m_xSupplier.is() )
     {
         Reference< lang::XMultiServiceFactory > xMSF = ::comphelper::getProcessServiceFactory();
-        Reference< util::XNumberFormatsSupplier > xSupplier( xMSF->createInstance( 
+        Reference< util::XNumberFormatsSupplier > xSupplier( xMSF->createInstance(
             ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.util.NumberFormatsSupplier") ) ), UNO_QUERY );
-        
+
         ::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
         if ( !m_xSupplier.is() )
         {
@@ -503,7 +481,6 @@ Reference< util::XNumberFormatsSupplier > const & DlgEditor::GetNumberFormatsSup
     return m_xSupplier;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::MouseButtonDown( const MouseEvent& rMEvt )
 {
@@ -512,31 +489,27 @@ void DlgEditor::MouseButtonDown( const MouseEvent& rMEvt )
     pFunc->MouseButtonDown( rMEvt );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::MouseButtonUp( const MouseEvent& rMEvt )
 {
-    BOOL bRet = pFunc->MouseButtonUp( rMEvt );
+    sal_Bool bRet = pFunc->MouseButtonUp( rMEvt );
 
     if( (eMode == DLGED_INSERT) )
         bCreateOK = bRet;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::MouseMove( const MouseEvent& rMEvt )
 {
     pFunc->MouseMove( rMEvt );
 }
 
-//----------------------------------------------------------------------------
 
-BOOL DlgEditor::KeyInput( const KeyEvent& rKEvt )
+sal_Bool DlgEditor::KeyInput( const KeyEvent& rKEvt )
 {
     return pFunc->KeyInput( rKEvt );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::Paint( const Rectangle& rRect )
 {
@@ -544,7 +517,6 @@ void DlgEditor::Paint( const Rectangle& rRect )
     PaintTimeout( &aPaintTimer );
 }
 
-//----------------------------------------------------------------------------
 
 IMPL_LINK( DlgEditor, PaintTimeout, Timer *, EMPTYARG )
 {
@@ -558,13 +530,13 @@ IMPL_LINK( DlgEditor, PaintTimeout, Timer *, EMPTYARG )
         pWindow->IsVisible() &&
         (pWindow->GetOutputSize() != aMacSize) )
     {
-        bFirstDraw = FALSE;
+        bFirstDraw = sal_False;
 
         // get property set
         ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >  xPSet(pDlgEdForm->GetUnoControlModel(), ::com::sun::star::uno::UNO_QUERY);
 
         if ( xPSet.is() )
-        {		
+        {
             // get dialog size from properties
             sal_Int32 nWidth = 0, nHeight = 0;
             xPSet->getPropertyValue( DLGED_PROP_WIDTH ) >>= nWidth;
@@ -601,14 +573,14 @@ IMPL_LINK( DlgEditor, PaintTimeout, Timer *, EMPTYARG )
                 pDlgEdForm->SetSnapRect( Rectangle( aPos, aSize ) );
                 pDlgEdForm->EndListening(sal_False);
                 pDlgEdForm->SetPropsFromRect();
-                pDlgEdForm->GetDlgEditor()->SetDialogModelChanged(TRUE);
+                pDlgEdForm->GetDlgEditor()->SetDialogModelChanged(sal_True);
                 pDlgEdForm->StartListening();
 
                 // set position and size of controls
-                ULONG nObjCount;
+                sal_uLong nObjCount;
                 if ( pDlgEdPage && ( ( nObjCount = pDlgEdPage->GetObjCount() ) > 0 ) )
                 {
-                    for ( ULONG i = 0 ; i < nObjCount ; i++ )
+                    for ( sal_uLong i = 0 ; i < nObjCount ; i++ )
                     {
                         SdrObject* pObj = pDlgEdPage->GetObj(i);
                         DlgEdObj* pDlgEdObj = PTR_CAST(DlgEdObj, pObj);
@@ -656,7 +628,6 @@ IMPL_LINK( DlgEditor, PaintTimeout, Timer *, EMPTYARG )
     return 0;
 }
 
-//----------------------------------------------------------------------------
 
 IMPL_LINK( DlgEditor, MarkTimeout, Timer *, EMPTYARG )
 {
@@ -672,7 +643,6 @@ IMPL_LINK( DlgEditor, MarkTimeout, Timer *, EMPTYARG )
     return 1;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::SetMode( DlgEdMode eNewMode )
 {
@@ -685,10 +655,10 @@ void DlgEditor::SetMode( DlgEdMode eNewMode )
         else
             pFunc = new DlgEdFuncSelect( this );
 
-        if ( eNewMode == DLGED_READONLY )        
-            pDlgEdModel->SetReadOnly( TRUE );
+        if ( eNewMode == DLGED_READONLY )
+            pDlgEdModel->SetReadOnly( sal_True );
         else
-            pDlgEdModel->SetReadOnly( FALSE );
+            pDlgEdModel->SetReadOnly( sal_False );
     }
 
     if ( eNewMode == DLGED_TEST )
@@ -697,24 +667,21 @@ void DlgEditor::SetMode( DlgEdMode eNewMode )
     eMode = eNewMode;
 }
 
-//----------------------------------------------------------------------------
 
-void DlgEditor::SetInsertObj( USHORT eObj )
+void DlgEditor::SetInsertObj( sal_uInt16 eObj )
 {
     eActObj = eObj;
-    
+
     if( pDlgEdView )
-        pDlgEdView->SetCurrentObj( eActObj, DlgInventor );	
+        pDlgEdView->SetCurrentObj( eActObj, DlgInventor );
 }
 
-//----------------------------------------------------------------------------
 
-USHORT DlgEditor::GetInsertObj() const
+sal_uInt16 DlgEditor::GetInsertObj() const
 {
     return eActObj;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::CreateDefaultObject()
 {
@@ -743,7 +710,6 @@ void DlgEditor::CreateDefaultObject()
     }
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::Cut()
 {
@@ -751,7 +717,6 @@ void DlgEditor::Cut()
     Delete();
 }
 
-//----------------------------------------------------------------------------
 
 void implCopyStreamToByteSequence( Reference< XInputStream > xStream,
     Sequence< sal_Int8 >& bytes )
@@ -762,7 +727,7 @@ void implCopyStreamToByteSequence( Reference< XInputStream > xStream,
         Sequence< sal_Int8 > readBytes;
         nRead = xStream->readBytes( readBytes, 1024 );
         if (! nRead)
-            break;		
+            break;
 
         sal_Int32 nPos = bytes.getLength();
         bytes.realloc( nPos + nRead );
@@ -771,7 +736,7 @@ void implCopyStreamToByteSequence( Reference< XInputStream > xStream,
 }
 
 void DlgEditor::Copy()
-{	
+{
     if( !pDlgEdView->AreObjectsMarked() )
         return;
 
@@ -797,8 +762,8 @@ void DlgEditor::Copy()
     }
 
     // insert control models of marked objects into clipboard dialog model
-    ULONG nMark = pDlgEdView->GetMarkedObjectList().GetMarkCount();	
-    for( ULONG i = 0; i < nMark; i++ )
+    sal_uLong nMark = pDlgEdView->GetMarkedObjectList().GetMarkCount();
+    for( sal_uLong i = 0; i < nMark; i++ )
     {
         SdrObject* pObj = pDlgEdView->GetMarkedObjectList().GetMark(i)->GetMarkedSdrObj();
         DlgEdObj* pDlgEdObj = PTR_CAST(DlgEdObj, pObj);
@@ -925,7 +890,6 @@ void DlgEditor::Copy()
     }
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::Paste()
 {
@@ -967,7 +931,7 @@ void DlgEditor::Paste()
                 // create clipboard dialog model from xml
                 Reference< lang::XMultiServiceFactory > xMSF = getProcessServiceFactory();
                 Reference< container::XNameContainer > xClipDialogModel( xMSF->createInstance
-                    ( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.UnoControlDialogModel" ) ) ), 
+                    ( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.UnoControlDialogModel" ) ) ),
                         uno::UNO_QUERY );
 
                 bool bSourceIsLocalized = false;
@@ -1030,7 +994,7 @@ void DlgEditor::Paste()
                     {
                         Reference< lang::XMultiServiceFactory > xSMgr = getProcessServiceFactory();
                         xStringResourcePersistence = Reference< resource::XStringResourcePersistence >( xSMgr->createInstance
-                            ( ::rtl::OUString::createFromAscii( "com.sun.star.resource.StringResource" ) ), UNO_QUERY );
+                            ( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.resource.StringResource" )) ), UNO_QUERY );
                         if( xStringResourcePersistence.is() )
                             xStringResourcePersistence->importBinary( aResData );
                     }
@@ -1090,12 +1054,12 @@ void DlgEditor::Paste()
                         pDlgEdModel->GetPage(0)->InsertObject( pCtrlObj );
                         pCtrlObj->SetRectFromProps();
                         pCtrlObj->UpdateStep();
-                        pDlgEdForm->UpdateTabOrderAndGroups();              // #110559#
+                        pDlgEdForm->UpdateTabOrderAndGroups();
                         pCtrlObj->StartListening();							// start listening
 
                         // mark object
                         SdrPageView* pPgView = pDlgEdView->GetSdrPageView();
-                        pDlgEdView->MarkObj( pCtrlObj, pPgView, FALSE, TRUE);
+                        pDlgEdView->MarkObj( pCtrlObj, pPgView, sal_False, sal_True);
                     }
 
                     // center marked objects in dialog editor form
@@ -1106,15 +1070,14 @@ void DlgEditor::Paste()
                     pDlgEdView->MoveMarkedObj( aSize );						// update of control model properties (position + size) in NbcMove
                     pDlgEdView->MarkListHasChanged();
 
-                    // dialog model changed 
-                    SetDialogModelChanged(TRUE);
+                    // dialog model changed
+                    SetDialogModelChanged(sal_True);
                 }
             }
         }
     }
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::Delete()
 {
@@ -1122,9 +1085,9 @@ void DlgEditor::Delete()
         return;
 
     // remove control models of marked objects from dialog model
-    ULONG nMark = pDlgEdView->GetMarkedObjectList().GetMarkCount();	
+    sal_uLong nMark = pDlgEdView->GetMarkedObjectList().GetMarkCount();
 
-    for( ULONG i = 0; i < nMark; i++ )
+    for( sal_uLong i = 0; i < nMark; i++ )
     {
         SdrObject* pObj = pDlgEdView->GetMarkedObjectList().GetMark(i)->GetMarkedSdrObj();
         DlgEdObj* pDlgEdObj = PTR_CAST(DlgEdObj, pObj);
@@ -1165,18 +1128,17 @@ void DlgEditor::Delete()
 
     pDlgEdView->BrkAction();
 
-    BOOL bDlgMarked = UnmarkDialog();
+    sal_Bool bDlgMarked = UnmarkDialog();
     pDlgEdView->DeleteMarked();
     if( bDlgMarked )
         RemarkDialog();
 }
 
-//----------------------------------------------------------------------------
 
-BOOL DlgEditor::IsPasteAllowed()
+sal_Bool DlgEditor::IsPasteAllowed()
 {
-    BOOL bPaste = FALSE;
-    
+    sal_Bool bPaste = sal_False;
+
     // get clipboard
     Reference< datatransfer::clipboard::XClipboard > xClipboard = GetWindow()->GetClipboard();
     if ( xClipboard.is() )
@@ -1189,7 +1151,7 @@ BOOL DlgEditor::IsPasteAllowed()
         {
             if ( xTransf->isDataFlavorSupported( m_ClipboardDataFlavors[0] ) )
             {
-                bPaste = TRUE;
+                bPaste = sal_True;
             }
         }
     }
@@ -1197,39 +1159,34 @@ BOOL DlgEditor::IsPasteAllowed()
     return bPaste;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::ShowProperties()
 {
     BasicIDEShell* pIDEShell = IDE_DLL()->GetShell();
-    SfxViewFrame* pViewFrame = pIDEShell ? pIDEShell->GetViewFrame() : NULL;        
+    SfxViewFrame* pViewFrame = pIDEShell ? pIDEShell->GetViewFrame() : NULL;
     if ( pViewFrame && !pViewFrame->HasChildWindow( SID_SHOW_PROPERTYBROWSER ) )
         pViewFrame->ToggleChildWindow( SID_SHOW_PROPERTYBROWSER );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::UpdatePropertyBrowserDelayed()
 {
     aMarkTimer.Start();
 }
 
-//----------------------------------------------------------------------------
 
-BOOL DlgEditor::IsModified() const
+sal_Bool DlgEditor::IsModified() const
 {
     return pDlgEdModel->IsChanged() || bDialogModelChanged;
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::ClearModifyFlag()
 {
-    pDlgEdModel->SetChanged( FALSE );
-    bDialogModelChanged = FALSE;
+    pDlgEdModel->SetChanged( sal_False );
+    bDialogModelChanged = sal_False;
 }
 
-//----------------------------------------------------------------------------
 
 #define LMARGPRN		1700
 #define RMARGPRN		 900
@@ -1237,7 +1194,6 @@ void DlgEditor::ClearModifyFlag()
 #define BMARGPRN    	1000
 #define BORDERPRN		300
 
-//----------------------------------------------------------------------------
 
 void lcl_PrintHeader( Printer* pPrinter, const String& rTitle )	// not working yet
 {
@@ -1278,7 +1234,6 @@ void lcl_PrintHeader( Printer* pPrinter, const String& rTitle )	// not working y
     pPrinter->Pop();
 }
 
-//----------------------------------------------------------------------------
 
 sal_Int32 DlgEditor::countPages( Printer* )
 {
@@ -1291,7 +1246,6 @@ void DlgEditor::printPage( sal_Int32 nPage, Printer* pPrinter, const String& rTi
         Print( pPrinter, rTitle );
 }
 
-//----------------------------------------------------------------------------
 
 void DlgEditor::Print( Printer* pPrinter, const String& rTitle )	// not working yet
 {
@@ -1303,9 +1257,6 @@ void DlgEditor::Print( Printer* pPrinter, const String& rTitle )	// not working
         MapMode aMap( MAP_100TH_MM );
         pPrinter->SetMapMode( aMap );
         Font aFont;
-#ifdef OS2
-        //aFont.SetName( System::GetStandardFont( STDFONT_SWISS ).GetName() );
-#endif
         aFont.SetAlign( ALIGN_BOTTOM );
         aFont.SetSize( Size( 0, 360 ));
         pPrinter->SetFont( aFont );
@@ -1319,15 +1270,12 @@ void DlgEditor::Print( Printer* pPrinter, const String& rTitle )	// not working
         Bitmap aDlg;
 #ifdef OS2
         Bitmap* pDlg = new Bitmap;
-        //pSbxForm->SnapShot( *pDlg );
         SvMemoryStream* pStrm = new SvMemoryStream;
         *pStrm << *pDlg;
         delete pDlg;
         pStrm->Seek(0);
         *pStrm >> aDlg;
         delete pStrm;
-#else
-        //pSbxForm->SnapShot( aDlg );
 #endif
         Size aBmpSz( pPrinter->PixelToLogic( aDlg.GetSizePixel() ) );
         double nPaperSzWidth = aPaperSz.Width();
@@ -1363,7 +1311,6 @@ void DlgEditor::Print( Printer* pPrinter, const String& rTitle )	// not working
     }
 }
 
-//----------------------------------------------------------------------------
 
 bool DlgEditor::AdjustPageSize()
 {
@@ -1420,6 +1367,4 @@ bool DlgEditor::AdjustPageSize()
     return bAdjustedPageSize;
 }
 
-//----------------------------------------------------------------------------
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
