@@ -99,7 +99,6 @@ JNIEXPORT jlong JNICALL Java_com_sun_star_comp_beans_LocalOfficeWindow_getNative
     JAWT_X11DrawingSurfaceInfo* dsi_x11;
 
     Drawable drawable;
-    Display* display;
 
     /* Get the AWT */
     awt.version = JAWT_VERSION_1_3;
@@ -124,7 +123,6 @@ JNIEXPORT jlong JNICALL Java_com_sun_star_comp_beans_LocalOfficeWindow_getNative
     dsi_x11 = (JAWT_X11DrawingSurfaceInfo*)dsi->platformInfo;
     
     drawable = dsi_x11->drawable;
-    display  = dsi_x11->display;
 
     /* Free the drawing surface info */
     ds->FreeDrawingSurfaceInfo(dsi);
