@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include "hangulhanjadlg.hxx"
 #include "hangulhanjadlg.hrc"
 #include "commonlingui.hxx"
@@ -52,21 +49,12 @@
 #include <comphelper/processfactory.hxx>
 
 #define HHC editeng::HangulHanjaConversion
-#define LINE_CNT        static_cast< USHORT >(2)
+#define LINE_CNT        static_cast< sal_uInt16 >(2)
 
 //.............................................................................
 namespace svx
 {
 //.............................................................................
-/*
-    using HangulHanjaConversion::eSimpleConversion;
-    using HangulHanjaConversion::eHangulBracketed;
-    using HangulHanjaConversion::eHanjaBracketed;
-    using HangulHanjaConversion::eRubyHanjaAbove;
-    using HangulHanjaConversion::eRubyHanjaBelow;
-    using HangulHanjaConversion::eRubyHangulAbove;
-    using HangulHanjaConversion::eRubyHangulBelow;
-*/
     using namespace ::com::sun::star;
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::linguistic2;
@@ -119,7 +107,7 @@ namespace svx
         PseudoRubyText( const String& _rPrimary, const String& _rSecondary, const RubyPosition _ePosition );
 
     public:
-        void Paint( OutputDevice& _rDevice, const Rectangle& _rRect, USHORT _nTextStyle,
+        void Paint( OutputDevice& _rDevice, const Rectangle& _rRect, sal_uInt16 _nTextStyle,
             Rectangle* _pPrimaryLocation = NULL, Rectangle* _pSecondaryLocation = NULL,
             ::vcl::ControlLayoutData* _pLayoutData = NULL );
     };
@@ -133,7 +121,7 @@ namespace svx
     }
 
     //-------------------------------------------------------------------------
-    void PseudoRubyText::Paint( OutputDevice& _rDevice, const Rectangle& _rRect, USHORT _nTextStyle,
+    void PseudoRubyText::Paint( OutputDevice& _rDevice, const Rectangle& _rRect, sal_uInt16 _nTextStyle,
         Rectangle* _pPrimaryLocation, Rectangle* _pSecondaryLocation, ::vcl::ControlLayoutData* _pLayoutData )
     {
         bool			bLayoutOnly	 = NULL != _pLayoutData;
@@ -205,7 +193,7 @@ namespace svx
         // now draw the texts
         // as we already calculated the precise rectangles for the texts, we don't want to
         // use the alignment flags given - within it's rect, every text is centered
-        USHORT nDrawTextStyle( _nTextStyle );
+        sal_uInt16 nDrawTextStyle( _nTextStyle );
         nDrawTextStyle &= ~( TEXT_DRAW_RIGHT | TEXT_DRAW_LEFT | TEXT_DRAW_BOTTOM | TEXT_DRAW_TOP );
         nDrawTextStyle |= TEXT_DRAW_CENTER | TEXT_DRAW_VCENTER;
 
@@ -268,7 +256,7 @@ namespace svx
         ++aTextRect.Top(); --aTextRect.Bottom();
 
         // calculate the text flags for the painting
-        USHORT nTextStyle = TEXT_DRAW_MNEMONIC;
+        sal_uInt16 nTextStyle = TEXT_DRAW_MNEMONIC;
         WinBits nStyle = GetStyle( );
 
         // the horizontal alignment
@@ -338,7 +326,7 @@ namespace svx
     {
         OutputDevice*  pDev = rUDEvt.GetDevice();
         Rectangle aRect = rUDEvt.GetRect();
-        USHORT  nItemId = rUDEvt.GetItemId();
+        sal_uInt16  nItemId = rUDEvt.GetItemId();
 
         String sText = *static_cast< String* >( GetItemData( nItemId ) );
         pDev->DrawText( aRect, sText, TEXT_DRAW_CENTER | TEXT_DRAW_VCENTER );
@@ -346,7 +334,7 @@ namespace svx
 
     void SuggestionSet::ClearSet()
     {
-        USHORT i, nCount = GetItemCount();
+        sal_uInt16 i, nCount = GetItemCount();
         for ( i = 0; i < nCount; ++i )
             delete static_cast< String* >( GetItemData(i) );
         Clear();
@@ -370,7 +358,7 @@ namespace svx
         m_aValueSet.SetLineCount( LINE_CNT );
         m_aValueSet.SetStyle( m_aValueSet.GetStyle() | WB_ITEMBORDER | WB_FLATVALUESET | WB_VSCROLL );
         m_aValueSet.SetBorderStyle( WINDOW_BORDER_MONO );
-        String aOneCharacter(RTL_CONSTASCII_STRINGPARAM("AU"));
+        String aOneCharacter(RTL_CONSTASCII_USTRINGPARAM("AU"));
         long nItemWidth = 2*GetTextWidth( aOneCharacter );
         m_aValueSet.SetItemWidth( nItemWidth );
 
@@ -442,7 +430,7 @@ namespace svx
         if( m_bDisplayListBox != bDisplayListBox )
         {
             Control& rOldControl = implGetCurrentControl();
-            BOOL bHasFocus = rOldControl.HasFocus();
+            sal_Bool bHasFocus = rOldControl.HasFocus();
 
             m_bDisplayListBox = bDisplayListBox;
 
@@ -464,12 +452,12 @@ namespace svx
         m_bInSelectionUpdate = true;
         if(pControl==&m_aListBox)
         {
-            USHORT nPos = m_aListBox.GetSelectEntryPos();
+            sal_uInt16 nPos = m_aListBox.GetSelectEntryPos();
             m_aValueSet.SelectItem( nPos+1 ); //itemid == pos+1 (id 0 has special meaning)
         }
         else
         {
-            USHORT nPos = m_aValueSet.GetSelectItemId()-1; //itemid == pos+1 (id 0 has special meaning)
+            sal_uInt16 nPos = m_aValueSet.GetSelectItemId()-1; //itemid == pos+1 (id 0 has special meaning)
             m_aListBox.SelectEntryPos( nPos );
         }
         m_bInSelectionUpdate = false;
@@ -488,21 +476,21 @@ namespace svx
     }
     void SuggestionDisplay::InsertEntry( const XubString& rStr )
     {
-        USHORT nItemId = m_aListBox.InsertEntry( rStr ) + 1; //itemid == pos+1 (id 0 has special meaning)
+        sal_uInt16 nItemId = m_aListBox.InsertEntry( rStr ) + 1; //itemid == pos+1 (id 0 has special meaning)
         m_aValueSet.InsertItem( nItemId );
         String* pItemData = new String(rStr);
         m_aValueSet.SetItemData( nItemId, pItemData );
     }
-    void SuggestionDisplay::SelectEntryPos( USHORT nPos )
+    void SuggestionDisplay::SelectEntryPos( sal_uInt16 nPos )
     {
         m_aListBox.SelectEntryPos( nPos );
         m_aValueSet.SelectItem( nPos+1 ); //itemid == pos+1 (id 0 has special meaning)
     }
-    USHORT SuggestionDisplay::GetEntryCount() const
+    sal_uInt16 SuggestionDisplay::GetEntryCount() const
     {
         return m_aListBox.GetEntryCount();
     }
-    XubString SuggestionDisplay::GetEntry( USHORT nPos ) const
+    XubString SuggestionDisplay::GetEntry( sal_uInt16 nPos ) const
     {
         return m_aListBox.GetEntry( nPos );
     }
@@ -600,19 +588,15 @@ namespace svx
         m_pPlayground->SetButtonHandler( SvxCommonLinguisticControl::eOptions,
                                         LINK( this, HangulHanjaConversionDialog, OnOption ) );
         m_pPlayground->GetButton( SvxCommonLinguisticControl::eOptions )->Show();
-//		m_pPlayground->EnableButton( SvxCommonLinguisticControl::eOptions, true );
 
         if ( editeng::HangulHanjaConversion::eHangulToHanja == _ePrimaryDirection )
         {
-//			m_aHanjaOnly.Enable( sal_False );
             m_pIgnoreNonPrimary = &m_aHangulOnly;
         }
         else
         {
-//			m_aHangulOnly.Enable( sal_False );
             m_pIgnoreNonPrimary = &m_aHanjaOnly;
         }
-//        m_pIgnoreNonPrimary->Check();
 
         // initial focus
         FocusSuggestion( );
@@ -690,12 +674,6 @@ namespace svx
         m_pPlayground->SetButtonHandler( SvxCommonLinguisticControl::eChangeAll, _rHdl );
     }
 
-    //-------------------------------------------------------------------------
-    void HangulHanjaConversionDialog::SetOptionsHdl( const Link& _rHdl )
-    {
-        m_pPlayground->SetButtonHandler( SvxCommonLinguisticControl::eOptions, _rHdl );
-    }
-
     //-------------------------------------------------------------------------
     void HangulHanjaConversionDialog::SetFindHdl( const Link& _rHdl )
     {
@@ -761,9 +739,9 @@ namespace svx
             pOtherBox = &m_aHangulOnly;
         if (pBox && pOtherBox)
         {
-            BOOL bBoxChecked = pBox->IsChecked();
+            sal_Bool bBoxChecked = pBox->IsChecked();
             if (bBoxChecked)
-                pOtherBox->Check( FALSE );
+                pOtherBox->Check( sal_False );
             pOtherBox->Enable( !bBoxChecked );
         }
 
@@ -866,21 +844,16 @@ namespace svx
         m_aSuggestions.DisplayListBox( !_bByCharacter );
     }
 
-    //-------------------------------------------------------------------------
-    sal_Bool HangulHanjaConversionDialog::GetByCharacter( ) const
-    {
-        return m_aReplaceByChar.IsChecked();
-    }
     //-------------------------------------------------------------------------
     void HangulHanjaConversionDialog::SetConversionDirectionState(
             sal_Bool _bTryBothDirections,
             HHC::ConversionDirection _ePrimaryConversionDirection )
     {
         // default state: try both direction
-        m_aHangulOnly.Check( FALSE );
-        m_aHangulOnly.Enable( TRUE );
-        m_aHanjaOnly.Check( FALSE );
-        m_aHanjaOnly.Enable( TRUE );
+        m_aHangulOnly.Check( sal_False );
+        m_aHangulOnly.Enable( sal_True );
+        m_aHanjaOnly.Check( sal_False );
+        m_aHanjaOnly.Enable( sal_True );
 
         if (!_bTryBothDirections)
         {
@@ -894,8 +867,6 @@ namespace svx
     //-------------------------------------------------------------------------
     sal_Bool HangulHanjaConversionDialog::GetUseBothDirections( ) const
     {
-//		DBG_ASSERT( m_pIgnoreNonPrimary, "HangulHanjaConversionDialog::GetUseBothDirections: where's the check box pointer?" );
-//		return m_pIgnoreNonPrimary ? !m_pIgnoreNonPrimary->IsChecked( ) : sal_True;
         return !m_aHangulOnly.IsChecked() && !m_aHanjaOnly.IsChecked();
     }
 
@@ -924,7 +895,7 @@ namespace svx
             case HHC::eRubyHangulAbove: m_pHangulAbove->Check(); break;
             case HHC::eRubyHangulBelow: m_pHangulBelow->Check(); break;
         default:
-            DBG_ERROR( "HangulHanjaConversionDialog::SetConversionFormat: unknown type!" );
+            OSL_FAIL( "HangulHanjaConversionDialog::SetConversionFormat: unknown type!" );
         }
     }
 
@@ -946,7 +917,7 @@ namespace svx
         if ( m_pHangulBelow->IsChecked() )
             return HHC::eRubyHangulBelow;
 
-        DBG_ERROR( "HangulHanjaConversionDialog::GetConversionFormat: no radio checked?" );
+        OSL_FAIL( "HangulHanjaConversionDialog::GetConversionFormat: no radio checked?" );
         return HHC::eSimpleConversion;
     }
 
@@ -1121,7 +1092,7 @@ namespace svx
 
     IMPL_LINK( HangulHanjaOptionsDialog, DeleteDictHdl, void*, EMPTYARG )
     {
-        USHORT nSelPos = m_aDictsLB.GetSelectEntryPos();
+        sal_uInt16 nSelPos = m_aDictsLB.GetSelectEntryPos();
         if( nSelPos != LISTBOX_ENTRY_NOTFOUND )
         {
             Reference< XConversionDictionary >	xDic( m_aDictList[ nSelPos ] );
@@ -1170,10 +1141,9 @@ namespace svx
         ,m_pCheckButtonData		( NULL )
         ,m_xConversionDictionaryList( NULL )
     {
-        m_aDictsLB.SetWindowBits( WB_CLIPCHILDREN | WB_HSCROLL | WB_FORCE_MAKEVISIBLE );
+        m_aDictsLB.SetStyle( m_aDictsLB.GetStyle() | WB_CLIPCHILDREN | WB_HSCROLL | WB_FORCE_MAKEVISIBLE );
         m_aDictsLB.SetSelectionMode( SINGLE_SELECTION );
         m_aDictsLB.SetHighlightRange();
-//		m_aDictsLB.SetHelpId( xxx );
         m_aDictsLB.SetSelectHdl( LINK( this, HangulHanjaOptionsDialog, DictsLB_SelectHdl ) );
         m_aDictsLB.SetDeselectHdl( LINK( this, HangulHanjaOptionsDialog, DictsLB_SelectHdl ) );
 
@@ -1498,8 +1468,8 @@ namespace svx
         {
             const KeyEvent*				pKEvt = rNEvt.GetKeyEvent();
             const KeyCode&				rKeyCode = pKEvt->GetKeyCode();
-            USHORT						nMod = rKeyCode.GetModifier();
-            USHORT						nCode = rKeyCode.GetCode();
+            sal_uInt16						nMod = rKeyCode.GetModifier();
+            sal_uInt16						nCode = rKeyCode.GetCode();
             if( nCode == KEY_TAB && ( !nMod || KEY_SHIFT == nMod ) )
             {
                 bool		bUp = KEY_SHIFT == nMod;
@@ -1765,13 +1735,13 @@ namespace svx
 
             //fill found entries into boxes
             sal_uInt32 nCnt = aEntries.getLength();
-            sal_uInt32 n = 0;
             if( nCnt )
             {
                 if( !m_pSuggestions )
                     m_pSuggestions = new SuggestionList( MAXNUM_SUGGESTIONS );
 
                 const OUString* pSugg = aEntries.getConstArray();
+                sal_uInt32 n = 0;
                 while( nCnt )
                 {
                     m_pSuggestions->Set( pSugg[ n ], sal_uInt16( n ) );
@@ -1882,7 +1852,7 @@ namespace svx
                 aName = xDic->getName();
             m_aBookLB.InsertEntry( aName );
         }
-        m_aBookLB.SelectEntryPos( USHORT( _nSelDict ) );
+        m_aBookLB.SelectEntryPos( sal_uInt16( _nSelDict ) );
 
         FreeResource();
 
