@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include <tools/shl.hxx>
 #include <svl/eitem.hxx>
 #include <sfx2/app.hxx>
@@ -82,8 +80,8 @@ SvxGrfCropPage::SvxGrfCropPage ( Window *pParent, const SfxItemSet &rSet )
     aOrigSizePB( 	this, CUI_RES( PB_ORGSIZE )),
     aExampleWN(     this, CUI_RES( WN_BSP     )),
     pLastCropField(0),
-    bInitialized(FALSE),
-    bSetOrigSize(FALSE)
+    bInitialized(sal_False),
+    bSetOrigSize(sal_False)
 {
     FreeResource();
 
@@ -134,28 +132,19 @@ SvxGrfCropPage::SvxGrfCropPage ( Window *pParent, const SfxItemSet &rSet )
 
     aTimer.SetTimeoutHdl(LINK(this, SvxGrfCropPage, Timeout));
     aTimer.SetTimeout( 1500 );
-}
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
+    aOrigSizePB.SetAccessibleRelationLabeledBy( &aOrigSizeFT );
+}
 
 SvxGrfCropPage::~SvxGrfCropPage()
 {
     aTimer.Stop();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SfxTabPage* SvxGrfCropPage::Create(Window *pParent, const SfxItemSet &rSet)
 {
     return new SvxGrfCropPage( pParent, rSet );
 }
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
 
 void SvxGrfCropPage::Reset( const SfxItemSet &rSet )
 {
@@ -163,7 +152,7 @@ void SvxGrfCropPage::Reset( const SfxItemSet &rSet )
     const SfxItemPool& rPool = *rSet.GetPool();
 
     if(SFX_ITEM_SET == rSet.GetItemState( rPool.GetWhich(
-                                    SID_ATTR_GRAF_KEEP_ZOOM ), TRUE, &pItem ))
+                                    SID_ATTR_GRAF_KEEP_ZOOM ), sal_True, &pItem ))
     {
         if( ((const SfxBoolItem*)pItem)->GetValue() )
             aZoomConstRB.Check();
@@ -172,8 +161,8 @@ void SvxGrfCropPage::Reset( const SfxItemSet &rSet )
         aZoomConstRB.SaveValue();
     }
 
-    USHORT nW = rPool.GetWhich( SID_ATTR_GRAF_CROP );
-    if( SFX_ITEM_SET == rSet.GetItemState( nW, TRUE, &pItem))
+    sal_uInt16 nW = rPool.GetWhich( SID_ATTR_GRAF_CROP );
+    if( SFX_ITEM_SET == rSet.GetItemState( nW, sal_True, &pItem))
     {
         FieldUnit eUnit = MapToFieldUnit( rSet.GetPool()->GetMetric( nW ));
 
@@ -198,7 +187,7 @@ void SvxGrfCropPage::Reset( const SfxItemSet &rSet )
     }
 
     nW = rPool.GetWhich( SID_ATTR_PAGE_SIZE );
-    if ( SFX_ITEM_SET == rSet.GetItemState( nW, FALSE, &pItem ) )
+    if ( SFX_ITEM_SET == rSet.GetItemState( nW, sal_False, &pItem ) )
     {
         // Orientation und Size aus dem PageItem
         FieldUnit eUnit = MapToFieldUnit( rSet.GetPool()->GetMetric( nW ));
@@ -221,8 +210,8 @@ void SvxGrfCropPage::Reset( const SfxItemSet &rSet )
                         MapMode( (MapUnit)rSet.GetPool()->GetMetric( nW ) ) );
     }
 
-    BOOL bFound = FALSE;
-    if( SFX_ITEM_SET == rSet.GetItemState( SID_ATTR_GRAF_GRAPHIC, FALSE, &pItem ) )
+    sal_Bool bFound = sal_False;
+    if( SFX_ITEM_SET == rSet.GetItemState( SID_ATTR_GRAF_GRAPHIC, sal_False, &pItem ) )
     {
         const Graphic* pGrf = ((SvxBrushItem*)pItem)->GetGraphic();
         if( pGrf )
@@ -234,30 +223,26 @@ void SvxGrfCropPage::Reset( const SfxItemSet &rSet )
             aExampleWN.SetGraphic( *pGrf );
             aExampleWN.SetFrameSize( aOrigSize );
 
-            bFound = TRUE;
+            bFound = sal_True;
             if( ((SvxBrushItem*)pItem)->GetGraphicLink() )
                 aGraphicName = *((SvxBrushItem*)pItem)->GetGraphicLink();
         }
     }
 
     GraphicHasChanged( bFound );
-    bReset = TRUE;
+    bReset = sal_True;
     ActivatePage( rSet );
-    bReset = FALSE;
+    bReset = sal_False;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-BOOL SvxGrfCropPage::FillItemSet(SfxItemSet &rSet)
+sal_Bool SvxGrfCropPage::FillItemSet(SfxItemSet &rSet)
 {
     const SfxItemPool& rPool = *rSet.GetPool();
-    BOOL bModified = FALSE;
+    sal_Bool bModified = sal_False;
     if( aWidthMF.GetSavedValue() != aWidthMF.GetText() ||
         aHeightMF.GetSavedValue() != aHeightMF.GetText() )
     {
-        USHORT nW = rPool.GetWhich( SID_ATTR_GRAF_FRMSIZE );
+        sal_uInt16 nW = rPool.GetWhich( SID_ATTR_GRAF_FRMSIZE );
         FieldUnit eUnit = MapToFieldUnit( rSet.GetPool()->GetMetric( nW ));
 
         SvxSizeItem aSz( nW );
@@ -267,7 +252,7 @@ BOOL SvxGrfCropPage::FillItemSet(SfxItemSet &rSet)
         const SfxItemSet* pExSet = GetTabDialog() ? GetTabDialog()->GetExampleSet() : NULL;
         const SfxPoolItem* pItem = 0;
         if( pExSet && SFX_ITEM_SET ==
-                pExSet->GetItemState( nW, FALSE, &pItem ) )
+                pExSet->GetItemState( nW, sal_False, &pItem ) )
             aSz = *(const SvxSizeItem*)pItem;
         else
             aSz = (const SvxSizeItem&)GetItemSet().Get( nW );
@@ -292,7 +277,7 @@ BOOL SvxGrfCropPage::FillItemSet(SfxItemSet &rSet)
     if( aLeftMF.IsModified() || aRightMF.IsModified() ||
         aTopMF.IsModified()  ||	aBottomMF.IsModified() )
     {
-        USHORT nW = rPool.GetWhich( SID_ATTR_GRAF_CROP );
+        sal_uInt16 nW = rPool.GetWhich( SID_ATTR_GRAF_CROP );
         FieldUnit eUnit = MapToFieldUnit( rSet.GetPool()->GetMetric( nW ));
         SvxGrfCrop* pNew = (SvxGrfCrop*)rSet.Get( nW ).Clone();
 
@@ -310,15 +295,11 @@ BOOL SvxGrfCropPage::FillItemSet(SfxItemSet &rSet)
                     SID_ATTR_GRAF_KEEP_ZOOM), aZoomConstRB.IsChecked() ) );
     }
 
-    bInitialized = FALSE;
+    bInitialized = sal_False;
 
     return bModified;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SvxGrfCropPage::ActivatePage(const SfxItemSet& rSet)
 {
 #ifdef DBG_UTIL
@@ -326,12 +307,12 @@ void SvxGrfCropPage::ActivatePage(const SfxItemSet& rSet)
     DBG_ASSERT( pPool, "Wo ist der Pool" );
 #endif
 
-    bSetOrigSize = FALSE;
+    bSetOrigSize = sal_False;
 
     // Size
     Size aSize;
     const SfxPoolItem* pItem;
-    if( SFX_ITEM_SET == rSet.GetItemState( SID_ATTR_GRAF_FRMSIZE, FALSE, &pItem ) )
+    if( SFX_ITEM_SET == rSet.GetItemState( SID_ATTR_GRAF_FRMSIZE, sal_False, &pItem ) )
         aSize = ((const SvxSizeItem*)pItem)->GetSize();
 
     nOldWidth = aSize.Width();
@@ -365,9 +346,9 @@ void SvxGrfCropPage::ActivatePage(const SfxItemSet& rSet)
             aHeightMF.SetValue(nHeight, FUNIT_TWIP);
     }
     aHeightMF.SaveValue();
-    bInitialized = TRUE;
+    bInitialized = sal_True;
 
-    if( SFX_ITEM_SET == rSet.GetItemState( SID_ATTR_GRAF_GRAPHIC, FALSE, &pItem ) )
+    if( SFX_ITEM_SET == rSet.GetItemState( SID_ATTR_GRAF_GRAPHIC, sal_False, &pItem ) )
     {
         const SvxBrushItem& rBrush = *(SvxBrushItem*)pItem;
         if( rBrush.GetGraphicLink() &&
@@ -384,21 +365,17 @@ void SvxGrfCropPage::ActivatePage(const SfxItemSet& rSet)
             CalcMinMaxBorder();
         }
         else
-            GraphicHasChanged( FALSE );
+            GraphicHasChanged( sal_False );
     }
 
     CalcZoom();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 int SvxGrfCropPage::DeactivatePage(SfxItemSet *_pSet)
 {
     if ( _pSet )
         FillItemSet( *_pSet );
-    return TRUE;
+    return sal_True;
 }
 
 /*--------------------------------------------------------------------
@@ -453,7 +430,7 @@ IMPL_LINK( SvxGrfCropPage, SizeHdl, MetricField *, pField )
                   lcl_GetValue(aRightMF, eUnit) );
         if(!nWidth)
             nWidth++;
-        USHORT nZoom = (USHORT)( aSize.Width() * 100L / nWidth);
+        sal_uInt16 nZoom = (sal_uInt16)( aSize.Width() * 100L / nWidth);
         aWidthZoomMF.SetValue(nZoom);
     }
     else
@@ -463,7 +440,7 @@ IMPL_LINK( SvxGrfCropPage, SizeHdl, MetricField *, pField )
                   lcl_GetValue(aBottomMF, eUnit));
         if(!nHeight)
             nHeight++;
-        USHORT nZoom = (USHORT)( aSize.Height() * 100L/ nHeight);
+        sal_uInt16 nZoom = (sal_uInt16)( aSize.Height() * 100L/ nHeight);
         aHeightZoomMF.SetValue(nZoom);
     }
 
@@ -481,7 +458,7 @@ IMPL_LINK( SvxGrfCropPage, CropHdl, const MetricField *, pField )
     FieldUnit eUnit = MapToFieldUnit( pPool->GetMetric( pPool->GetWhich(
                                                     SID_ATTR_GRAF_CROP ) ) );
 
-    BOOL bZoom = aZoomConstRB.IsChecked();
+    sal_Bool bZoom = aZoomConstRB.IsChecked();
     if( pField == &aLeftMF || pField == &aRightMF )
     {
         long nLeft = lcl_GetValue( aLeftMF, eUnit );
@@ -492,16 +469,12 @@ IMPL_LINK( SvxGrfCropPage, CropHdl, const MetricField *, pField )
         {
             if(pField == &aLeftMF)
             {
-//				nLeft = aPageSize.Width() -
-//					((nRight + aOrigSize.Width()) * nWidthZoom) / 100;
                 nLeft = aOrigSize.Width() -
                             ( aPageSize.Width() * 100 / nWidthZoom + nRight );
                 aLeftMF.SetValue( aLeftMF.Normalize( nLeft ), eUnit );
             }
             else
             {
-//				nRight = aPageSize.Width() -
-//					((nLeft - aOrigSize.Width()) * nWidthZoom) / 100;
                 nRight = aOrigSize.Width() -
                             ( aPageSize.Width() * 100 / nWidthZoom + nLeft );
                 aRightMF.SetValue( aRightMF.Normalize( nRight ), eUnit );
@@ -525,16 +498,12 @@ IMPL_LINK( SvxGrfCropPage, CropHdl, const MetricField *, pField )
         {
             if(pField == &aTopMF)
             {
-//				nTop = aPageSize.Height() -
-//					((aOrigSize.Height() - nBottom) * nHeightZoom)/ 100;
                 nTop = aOrigSize.Height() -
                             ( aPageSize.Height() * 100 / nHeightZoom + nBottom);
                 aTopMF.SetValue( aWidthMF.Normalize( nTop ), eUnit );
             }
             else
             {
-//				nBottom = aPageSize.Height() -
-//					((aOrigSize.Height() - nTop)*nHeightZoom) / 100;
                 nBottom = aOrigSize.Height() -
                             ( aPageSize.Height() * 100 / nHeightZoom + nTop);
                 aBottomMF.SetValue( aWidthMF.Normalize( nBottom ), eUnit );
@@ -576,7 +545,7 @@ IMPL_LINK( SvxGrfCropPage, OrigSizeHdl, PushButton *, EMPTYARG )
     aHeightMF.SetValue( aHeightMF.Normalize( nHeight ), eUnit );
     aWidthZoomMF.SetValue(100);
     aHeightZoomMF.SetValue(100);
-    bSetOrigSize = TRUE;
+    bSetOrigSize = sal_True;
     return 0;
 }
 /*--------------------------------------------------------------------
@@ -596,13 +565,13 @@ void SvxGrfCropPage::CalcZoom()
                       lcl_GetValue( aRightMF, eUnit );
     long nULBorders = lcl_GetValue( aTopMF, eUnit ) +
                       lcl_GetValue( aBottomMF, eUnit );
-    USHORT nZoom = 0;
+    sal_uInt16 nZoom = 0;
     long nDen;
     if( (nDen = aOrigSize.Width() - nLRBorders) > 0)
-        nZoom = (USHORT)((( nWidth  * 1000L / nDen )+5)/10);
+        nZoom = (sal_uInt16)((( nWidth  * 1000L / nDen )+5)/10);
     aWidthZoomMF.SetValue(nZoom);
     if( (nDen = aOrigSize.Height() - nULBorders) > 0)
-        nZoom = (USHORT)((( nHeight * 1000L / nDen )+5)/10);
+        nZoom = (sal_uInt16)((( nHeight * 1000L / nDen )+5)/10);
     else
         nZoom = 0;
     aHeightZoomMF.SetValue(nZoom);
@@ -627,11 +596,6 @@ void SvxGrfCropPage::CalcMinMaxBorder()
     nMin = nMinWidth - (nL >= 0 ? nL : 0);
     aRightMF.SetMax( aRightMF.Normalize(nMin), eUnit );
 
-    // Zoom nicht unter 2%
-/*	nMin = (aOrigSize.Width() * 102) /100;
-    aLeftMF.SetMax(aPageSize.Width() - nR - nMin);
-    aRightMF.SetMax(aPageSize.Width() - nL - nMin);
-*/
     long nUp  = lcl_GetValue( aTopMF, eUnit );
     long nMinHeight = (aOrigSize.Height() * 10) /11;
     nMin = nMinHeight - (nUp >= 0 ? nUp : 0);
@@ -640,18 +604,13 @@ void SvxGrfCropPage::CalcMinMaxBorder()
     long nLow = lcl_GetValue(aBottomMF, eUnit );
     nMin = nMinHeight - (nLow >= 0 ? nLow : 0);
     aTopMF.SetMax( aTopMF.Normalize(nMin), eUnit );
-
-    // Zoom nicht unter 2%
-/*	nMin = (aOrigSize.Height() * 102) /100;
-    aTopMF.SetMax(aPageSize.Height() - nLow - nMin);
-    aBottomMF.SetMax(aPageSize.Height() - nUp - nMin);*/
 }
 /*--------------------------------------------------------------------
     Beschreibung: 	Spinsize auf 1/20 der Originalgroesse setzen,
                     FixedText mit der Originalgroesse fuellen
  --------------------------------------------------------------------*/
 
-void SvxGrfCropPage::GraphicHasChanged( BOOL bFound )
+void SvxGrfCropPage::GraphicHasChanged( sal_Bool bFound )
 {
     if( bFound )
     {
@@ -830,6 +789,4 @@ void SvxGrfCropPage::SvxCropExample::SetFrameSize( const Size& rSz )
     Invalidate();
 }
 
-
-
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
