@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include <tools/shl.hxx>
 #include <tools/urlobj.hxx>
 #include <vcl/msgbox.hxx>
@@ -53,6 +50,7 @@
 #include <dialmgr.hxx>
 #include "svx/dlgutil.hxx"
 #include <svx/dialmgr.hxx>
+#include "paragrph.hrc"
 #include <svx/dialogs.hrc>
 
 #define DLGWIN this->GetParent()->GetParent()
@@ -104,9 +102,6 @@ SvxHatchTabPage::SvxHatchTabPage
     rXFSet              ( aXFillAttr.GetItemSet() )
 
 {
-    aBtnLoad.SetModeImage( Image( CUI_RES( RID_SVXIMG_LOAD_H ) ), BMP_COLOR_HIGHCONTRAST );
-    aBtnSave.SetModeImage( Image( CUI_RES( RID_SVXIMG_SAVE_H ) ), BMP_COLOR_HIGHCONTRAST );
-
     FreeResource();
 
     // diese Page braucht ExchangeSupport
@@ -152,6 +147,15 @@ SvxHatchTabPage::SvxHatchTabPage
     aBtnSave.SetClickHdl( LINK( this, SvxHatchTabPage, ClickSaveHdl_Impl ) );
 
     aCtlPreview.SetDrawMode( GetSettings().GetStyleSettings().GetHighContrastMode() ? OUTPUT_DRAWMODE_CONTRAST : OUTPUT_DRAWMODE_COLOR );
+
+    aCtlPreview.SetAccessibleName(String(CUI_RES(STR_EXAMPLE))); 
+    aLbHatchings.SetAccessibleName( String(CUI_RES(STR_LB_HATCHINGSTYLE)) );	
+    aCtlAngle.SetAccessibleRelationMemberOf( &aFlProp );
+    aLbHatchings.SetAccessibleRelationMemberOf( &aFlProp );
+    aBtnAdd.SetAccessibleRelationMemberOf( &aFlProp );
+    aBtnModify.SetAccessibleRelationMemberOf( &aFlProp );
+    aBtnDelete.SetAccessibleRelationMemberOf( &aFlProp );	
+    aLbHatchings.SetAccessibleRelationLabeledBy(&aLbHatchings);
 }
 
 // -----------------------------------------------------------------------
@@ -169,12 +173,12 @@ void SvxHatchTabPage::Construct()
 
 void SvxHatchTabPage::ActivatePage( const SfxItemSet& rSet )
 {
-    USHORT nPos;
-    USHORT nCount;
+    sal_uInt16 nPos;
+    sal_uInt16 nCount;
 
     if( *pDlgType == 0 ) // Flaechen-Dialog
     {
-        *pbAreaTP = FALSE;
+        *pbAreaTP = sal_False;
 
         if( pColorTab )
         {
@@ -288,14 +292,12 @@ long SvxHatchTabPage::CheckChanges_Impl()
             break;
 
             case RET_CANCEL:
-                // return( -1L ); <-- wuerde die Seite nicht verlassen
             break;
-            // return( TRUE ); // Abbruch
         }
         delete aMessDlg;
     }
 
-    USHORT nPos = aLbHatchings.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbHatchings.GetSelectEntryPos();
     if( nPos != LISTBOX_ENTRY_NOTFOUND )
         *pPos = nPos;
     return 0L;
@@ -303,9 +305,9 @@ long SvxHatchTabPage::CheckChanges_Impl()
 
 // -----------------------------------------------------------------------
 
-BOOL SvxHatchTabPage::FillItemSet( SfxItemSet& rSet )
+sal_Bool SvxHatchTabPage::FillItemSet( SfxItemSet& rSet )
 {
-    if( *pDlgType == 0 && *pbAreaTP == FALSE ) // Flaechen-Dialog
+    if( *pDlgType == 0 && *pbAreaTP == sal_False ) // Flaechen-Dialog
     {
         if( *pPageType == PT_HATCH )
         {
@@ -313,7 +315,7 @@ BOOL SvxHatchTabPage::FillItemSet( SfxItemSet& rSet )
 
             XHatch*	pXHatch = NULL;
             String	aString;
-            USHORT	nPos = aLbHatchings.GetSelectEntryPos();
+            sal_uInt16	nPos = aLbHatchings.GetSelectEntryPos();
             if( nPos != LISTBOX_ENTRY_NOTFOUND )
             {
                 pXHatch = new XHatch( pHatchingList->GetHatch( nPos )->GetHatch() );
@@ -334,14 +336,13 @@ BOOL SvxHatchTabPage::FillItemSet( SfxItemSet& rSet )
             delete pXHatch;
         }
     }
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
 
 void SvxHatchTabPage::Reset( const SfxItemSet& rSet )
 {
-    // aLbHatchings.SelectEntryPos( 0 );
     ChangeHatchHdl_Impl( this );
 
     // Status der Buttons ermitteln
@@ -418,10 +419,10 @@ IMPL_LINK( SvxHatchTabPage, ChangeHatchHdl_Impl, void *, EMPTYARG )
     else
     {
         const SfxPoolItem* pPoolItem = NULL;
-        if( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLSTYLE ), TRUE, &pPoolItem ) )
+        if( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLSTYLE ), sal_True, &pPoolItem ) )
         {
             if( ( XFILL_HATCH == (XFillStyle) ( ( const XFillStyleItem* ) pPoolItem )->GetValue() ) &&
-                ( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLHATCH ), TRUE, &pPoolItem ) ) )
+                ( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLHATCH ), sal_True, &pPoolItem ) ) )
             {
                 pHatch = new XHatch( ( ( const XFillHatchItem* ) pPoolItem )->GetHatchValue() );
             }
@@ -437,7 +438,7 @@ IMPL_LINK( SvxHatchTabPage, ChangeHatchHdl_Impl, void *, EMPTYARG )
     if( pHatch )
     {
         aLbLineType.SelectEntryPos(
-            sal::static_int_cast< USHORT >( pHatch->GetHatchStyle() ) );
+            sal::static_int_cast< sal_uInt16 >( pHatch->GetHatchStyle() ) );
         // Wenn der Eintrag nicht in der Listbox ist, wird die Farbe
         // temporaer hinzugenommen
         aLbLineColor.SetNoSelection();
@@ -464,19 +465,6 @@ IMPL_LINK( SvxHatchTabPage, ChangeHatchHdl_Impl, void *, EMPTYARG )
             default:  aCtlAngle.SetActualRP( RP_MM ); break;
         }
 
-        // Backgroundcolor
-        /*
-        const SfxPoolItem* pPoolItem = NULL;
-        if( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLBACKGROUND ), TRUE, &pPoolItem ) )
-        {
-            rXFSet.Put ( XFillBackgroundItem( ( ( XFillBackgroundItem* )pPoolItem)->GetValue() ) );
-            if( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLCOLOR ), TRUE, &pPoolItem ) )
-            {
-                Color aColor( ( ( const XFillColorItem* ) pPoolItem )->GetValue() );
-                rXFSet.Put( XFillColorItem( String(), aColor ) );
-            }
-        }
-        */
         // ItemSet fuellen und an aCtlPreview weiterleiten
         rXFSet.Put( XFillHatchItem( String(), *pHatch ) );
         aCtlPreview.SetAttributes( aXFillAttr.GetItemSet() );
@@ -504,18 +492,18 @@ IMPL_LINK( SvxHatchTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
 
     long nCount = pHatchingList->Count();
     long j = 1;
-    BOOL bDifferent = FALSE;
+    sal_Bool bDifferent = sal_False;
 
     while( !bDifferent )
     {
         aName  = aNewName;
         aName += sal_Unicode(' ');
         aName += UniString::CreateFromInt32( j++ );
-        bDifferent = TRUE;
+        bDifferent = sal_True;
 
         for( long i = 0; i < nCount && bDifferent; i++ )
             if( aName == pHatchingList->GetHatch( i )->GetName() )
-                bDifferent = FALSE;
+                bDifferent = sal_False;
     }
 
     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
@@ -523,17 +511,17 @@ IMPL_LINK( SvxHatchTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
     AbstractSvxNameDialog* pDlg = pFact->CreateSvxNameDialog( DLGWIN, aName, aDesc );
     DBG_ASSERT(pDlg, "Dialogdiet fail!");
     WarningBox*    pWarnBox = NULL;
-    USHORT         nError   = RID_SVXSTR_WARN_NAME_DUPLICATE;
+    sal_uInt16         nError   = RID_SVXSTR_WARN_NAME_DUPLICATE;
 
     while( pDlg->Execute() == RET_OK )
     {
         pDlg->GetName( aName );
 
-        bDifferent = TRUE;
+        bDifferent = sal_True;
 
         for( long i = 0; i < nCount && bDifferent; i++ )
             if( aName == pHatchingList->GetHatch( i )->GetName() )
-                bDifferent = FALSE;
+                bDifferent = sal_False;
 
         if( bDifferent ) {
             nError = 0;
@@ -551,7 +539,6 @@ IMPL_LINK( SvxHatchTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
         if( pWarnBox->Execute() != RET_OK )
             break;
     }
-    //Rectangle aDlgRect( pDlg->GetPosPixel(), pDlg->GetSizePixel() );
     delete pDlg;
     delete pWarnBox;
 
@@ -572,10 +559,9 @@ IMPL_LINK( SvxHatchTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
 #ifdef WNT
         // hack: #31355# W.P.
         Rectangle aRect( aLbHatchings.GetPosPixel(), aLbHatchings.GetSizePixel() );
-        if( TRUE ) {				// ??? overlapped with pDlg
+        if( sal_True ) {				// ??? overlapped with pDlg
                                     // and srolling
             Invalidate( aRect );
-            //aLbHatchings.Invalidate();
         }
 #endif
 
@@ -599,7 +585,7 @@ IMPL_LINK( SvxHatchTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
 
 IMPL_LINK( SvxHatchTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbHatchings.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbHatchings.GetSelectEntryPos();
 
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
@@ -615,23 +601,23 @@ IMPL_LINK( SvxHatchTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
         DBG_ASSERT(pDlg, "Dialogdiet fail!");
 
         long nCount = pHatchingList->Count();
-        BOOL bDifferent = FALSE;
-        BOOL bLoop = TRUE;
+        sal_Bool bDifferent = sal_False;
+        sal_Bool bLoop = sal_True;
         while( bLoop && pDlg->Execute() == RET_OK )
         {
             pDlg->GetName( aName );
-            bDifferent = TRUE;
+            bDifferent = sal_True;
 
             for( long i = 0; i < nCount && bDifferent; i++ )
             {
                 if( aName == pHatchingList->GetHatch( i )->GetName() &&
                     aName != aOldName )
-                    bDifferent = FALSE;
+                    bDifferent = sal_False;
             }
 
             if( bDifferent )
             {
-                bLoop = FALSE;
+                bLoop = sal_False;
                 XHatch aXHatch( aLbLineColor.GetSelectEntryColor(),
                                 (XHatchStyle) aLbLineType.GetSelectEntryPos(),
                                  GetCoreValue( aMtrDistance, ePoolUnit ),
@@ -671,7 +657,7 @@ IMPL_LINK( SvxHatchTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
 
 IMPL_LINK( SvxHatchTabPage, ClickDeleteHdl_Impl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbHatchings.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbHatchings.GetSelectEntryPos();
 
     if( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
@@ -707,7 +693,7 @@ IMPL_LINK( SvxHatchTabPage, ClickDeleteHdl_Impl, void *, EMPTYARG )
 IMPL_LINK( SvxHatchTabPage, ClickLoadHdl_Impl, void *, EMPTYARG )
 {
     ResMgr& rMgr = CUI_MGR();
-    USHORT nReturn = RET_YES;
+    sal_uInt16 nReturn = RET_YES;
 
     if ( *pnHatchingListState & CT_MODIFIED )
     {
@@ -741,39 +727,36 @@ IMPL_LINK( SvxHatchTabPage, ClickLoadHdl_Impl, void *, EMPTYARG )
             pHatchList->SetName( aURL.getName() );
             if( pHatchList->Load() )
             {
-                if( pHatchList )
+                // Pruefen, ob Tabelle geloescht werden darf:
+                if( pHatchingList != ( (SvxAreaTabDialog*) DLGWIN )->GetHatchingList() )
+                    delete pHatchingList;
+
+                pHatchingList = pHatchList;
+                ( (SvxAreaTabDialog*) DLGWIN )->SetNewHatchingList( pHatchingList );
+
+                aLbHatchings.Clear();
+                aLbHatchings.Fill( pHatchingList );
+                Reset( rOutAttrs );
+
+                pHatchingList->SetName( aURL.getName() );
+
+                // Ermitteln (evtl. abschneiden) des Namens und in
+                // der GroupBox darstellen
+                String aString( ResId( RID_SVXSTR_TABLE, rMgr ) );
+                aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( ": " ) );
+
+                if ( aURL.getBase().getLength() > 18 )
                 {
-                    // Pruefen, ob Tabelle geloescht werden darf:
-                    if( pHatchingList != ( (SvxAreaTabDialog*) DLGWIN )->GetHatchingList() )
-                        delete pHatchingList;
-
-                    pHatchingList = pHatchList;
-                    ( (SvxAreaTabDialog*) DLGWIN )->SetNewHatchingList( pHatchingList );
-
-                    aLbHatchings.Clear();
-                    aLbHatchings.Fill( pHatchingList );
-                    Reset( rOutAttrs );
-
-                    pHatchingList->SetName( aURL.getName() );
-
-                    // Ermitteln (evtl. abschneiden) des Namens und in
-                    // der GroupBox darstellen
-                    String aString( ResId( RID_SVXSTR_TABLE, rMgr ) );
-                    aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( ": " ) );
-
-                    if ( aURL.getBase().getLength() > 18 )
-                    {
-                        aString += String(aURL.getBase()).Copy( 0, 15 );
-                        aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( "..." ) );
-                    }
-                    else
-                        aString += String(aURL.getBase());
-
-                    // Flag fuer gewechselt setzen
-                    *pnHatchingListState |= CT_CHANGED;
-                    // Flag fuer modifiziert entfernen
-                    *pnHatchingListState &= ~CT_MODIFIED;
+                    aString += String(aURL.getBase()).Copy( 0, 15 );
+                    aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( "..." ) );
                 }
+                else
+                    aString += String(aURL.getBase());
+
+                // Flag fuer gewechselt setzen
+                *pnHatchingListState |= CT_CHANGED;
+                // Flag fuer modifiziert entfernen
+                *pnHatchingListState &= ~CT_MODIFIED;
             }
             else
                 ErrorBox( DLGWIN, WinBits( WB_OK ),
