@@ -222,36 +222,6 @@ extern "C"
         *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
     }
 
-    sal_Bool SAL_CALL component_writeInfo( void * //pServiceManager
-                                        , registry::XRegistryKey * pRegistryKey )
-    {
-        try
-        {
-            rtl::OUString sKey = rtl::OUString::createFromAscii("/");
-            sKey += BibliographyLoader::getImplementationName_Static();
-            //creates the impl key:  /com.sun.star.extensions.Bibliography
-            Reference< registry::XRegistryKey > xImplKey = pRegistryKey->createKey(sKey);
-
-
-            //sKey += rtl::OUString::createFromAscii("/UNO/SERVICES");
-            Reference< registry::XRegistryKey > xNewKey = xImplKey->createKey(	C2U("/UNO/SERVICES") );
-            Sequence< rtl::OUString > aServices = BibliographyLoader::getSupportedServiceNames_Static();
-            for( INT32 i = 0; i < aServices.getLength(); i++ )
-                xNewKey->createKey( aServices.getConstArray()[i]);
-            xNewKey = xImplKey->createKey(	C2U("/UNO/Loader"));
-
-            Reference< registry::XRegistryKey >  xPatternKey = xImplKey->createKey( C2U("/Loader/Pattern" ));
-            xPatternKey->setAsciiValue( C2U( ".component:Bibliography/*" ) );
-
-            return sal_True;
-        }
-        catch (Exception &)
-        {
-            return sal_False;
-        }
-    }
-
-
     void * SAL_CALL component_getFactory(
         const sal_Char * pImplName, XMultiServiceFactory * pServiceManager, void * /*pRegistryKey*/ )
     {
@@ -411,9 +381,7 @@ void BibliographyLoader::loadView(const Reference< XFrame > & rFrame, const rtl:
     if ( xLayoutManager.is() )
         xLayoutManager->createElement( OUString( RTL_CONSTASCII_USTRINGPARAM( "private:resource/menubar/menubar" )));
 }
-/* -----------------06.12.99 14:37-------------------
 
- --------------------------------------------------*/
 BibDataManager* BibliographyLoader::GetDataManager()const
 {
     if(!m_pDatMan)
@@ -425,9 +393,7 @@ BibDataManager* BibliographyLoader::GetDataManager()const
     }
     return m_pDatMan;
 }
-/* -----------------06.12.99 14:39-------------------
 
- --------------------------------------------------*/
 Reference< XNameAccess >  BibliographyLoader::GetDataColumns() const
 {
     if (!m_xColumns.is())
@@ -483,9 +449,7 @@ Reference< XNameAccess >  BibliographyLoader::GetDataColumns() const
 
     return m_xColumns;
 }
-/* -----------------17.12.99 12:29-------------------
 
- --------------------------------------------------*/
 Reference< sdb::XColumn >  BibliographyLoader::GetIdentifierColumn() const
 {
     BibDataManager* pDatMan = GetDataManager();
@@ -501,9 +465,6 @@ Reference< sdb::XColumn >  BibliographyLoader::GetIdentifierColumn() const
     return xReturn;
 }
 
-/* -----------------06.12.99 15:05-------------------
-
- --------------------------------------------------*/
 Reference< XResultSet >  BibliographyLoader::GetDataCursor() const
 {
     if (!m_xCursor.is())
@@ -513,9 +474,6 @@ Reference< XResultSet >  BibliographyLoader::GetDataCursor() const
     return m_xCursor;
 }
 
-/*-- 17.11.99 12:51:38---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 rtl::OUString lcl_AddProperty(Reference< XNameAccess >  xColumns,
         const Mapping* pMapping, const String& rColumnName)
 {
@@ -595,9 +553,7 @@ Any BibliographyLoader::getByName(const rtl::OUString& rName) throw
     }
     return aRet;
 }
-/*-- 17.11.99 12:51:39---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Sequence< rtl::OUString > BibliographyLoader::getElementNames(void) throw ( RuntimeException )
 {
     Sequence< rtl::OUString > aRet(10);
@@ -632,9 +588,7 @@ Sequence< rtl::OUString > BibliographyLoader::getElementNames(void) throw ( Runt
     aRet.realloc(nRealNameCount);
     return aRet;
 }
-/*-- 17.11.99 12:51:39---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool BibliographyLoader::hasByName(const rtl::OUString& rName) throw ( RuntimeException )
 {
     sal_Bool bRet = sal_False;
@@ -663,16 +617,12 @@ sal_Bool BibliographyLoader::hasByName(const rtl::OUString& rName) throw ( Runti
     }
     return bRet;
 }
-/*-- 17.11.99 12:51:39---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Type  BibliographyLoader::getElementType(void) throw ( RuntimeException )
 {
     return ::getCppuType((Sequence<PropertyValue>*)0);
 }
-/*-- 17.11.99 12:51:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool BibliographyLoader::hasElements(void) throw ( RuntimeException )
 {
     Reference< XResultSet >  xCursor = GetDataCursor();
@@ -680,9 +630,6 @@ sal_Bool BibliographyLoader::hasElements(void) throw ( RuntimeException )
     return xColumns.is() && (xColumns->getElementNames().getLength() != 0);
 }
 
-/*-- 07.12.99 14:28:39---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 Reference< XPropertySetInfo >  BibliographyLoader::getPropertySetInfo(void) throw
                                             ( RuntimeException )
 {
@@ -695,9 +642,7 @@ Reference< XPropertySetInfo >  BibliographyLoader::getPropertySetInfo(void) thro
         SfxItemPropertySet(aBibProps_Impl).getPropertySetInfo();
     return xRet;
 }
-/*-- 07.12.99 14:28:39---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void BibliographyLoader::setPropertyValue(const rtl::OUString& /*PropertyName*/,
                                         const Any& /*aValue*/)
     throw( UnknownPropertyException, PropertyVetoException,
@@ -706,9 +651,7 @@ void BibliographyLoader::setPropertyValue(const rtl::OUString& /*PropertyName*/,
     throw UnknownPropertyException();
     //no changeable properties
 }
-/*-- 07.12.99 14:28:39---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Any BibliographyLoader::getPropertyValue(const rtl::OUString& rPropertyName)
     throw( UnknownPropertyException, WrappedTargetException, RuntimeException )
 {
@@ -763,36 +706,28 @@ Any BibliographyLoader::getPropertyValue(const rtl::OUString& rPropertyName)
         throw UnknownPropertyException();
     return aRet;
 }
-/*-- 07.12.99 14:28:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void BibliographyLoader::addPropertyChangeListener(
         const rtl::OUString& /*PropertyName*/, const Reference< XPropertyChangeListener > & /*aListener*/)
         throw( UnknownPropertyException, WrappedTargetException, RuntimeException )
 {
     //no bound properties
 }
-/*-- 07.12.99 14:28:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void BibliographyLoader::removePropertyChangeListener(
         const rtl::OUString& /*PropertyName*/, const Reference< XPropertyChangeListener > & /*aListener*/)
         throw( UnknownPropertyException, WrappedTargetException, RuntimeException )
 {
     //no bound properties
 }
-/*-- 07.12.99 14:28:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void BibliographyLoader::addVetoableChangeListener(
     const rtl::OUString& /*PropertyName*/, const Reference< XVetoableChangeListener > & /*aListener*/)
     throw( UnknownPropertyException, WrappedTargetException, RuntimeException )
 {
     //no vetoable properties
 }
-/*-- 07.12.99 14:28:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void BibliographyLoader::removeVetoableChangeListener(
     const rtl::OUString& /*PropertyName*/, const Reference< XVetoableChangeListener > & /*aListener*/)
     throw( UnknownPropertyException, WrappedTargetException, RuntimeException )
