@@ -35,9 +35,7 @@
 #undef _LINUX_SOURCE_COMPAT
 #endif
 
-#if STLPORT_VERSION>=321
 #include <cstdarg>
-#endif
 
 #include <plugin/impl.hxx>
 #include <vcl/svapp.hxx>
@@ -101,7 +99,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
 
     MediatorMessage* pMessage;
     CommandAtoms nCommand;
-    while( (pMessage = GetNextMessage( FALSE )) )
+    while( (pMessage = GetNextMessage( sal_False )) )
     {
         nCommand = (CommandAtoms)pMessage->GetUINT32();
         medDebug( 1, "%s\n", GetCommandName( nCommand ) );
@@ -109,7 +107,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
         {
             case eNPN_GetURL:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 char* pUrl			= pMessage->GetString();
                 char* pWindow		= pMessage->GetString();
@@ -122,7 +120,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_GetURLNotify:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 char* pUrl			= pMessage->GetString();
                 char* pWindow		= pMessage->GetString();
@@ -138,13 +136,13 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_DestroyStream:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
-                UINT32 nFileID		= pMessage->GetUINT32();
+                sal_uInt32 nFileID		= pMessage->GetUINT32();
                 char* pUrl			= pMessage->GetString();
                 NPError* pReason	= (NPError*)pMessage->GetBytes();
                 NPError aRet = NPERR_FILE_NOT_FOUND;
-                if( nFileID < static_cast<UINT32>(m_aNPWrapStreams.size()) )
+                if( nFileID < static_cast<sal_uInt32>(m_aNPWrapStreams.size()) )
                 {
                     if( ! strcmp( m_aNPWrapStreams[ nFileID ]->url, pUrl ) )
                     {
@@ -169,7 +167,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_NewStream:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 NPMIMEType pType	= pMessage->GetString();
                 char* pTarget		= pMessage->GetString();
@@ -180,24 +178,24 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
 
                 if( aRet != NPERR_NO_ERROR )
                 {
-                    UINT32 nDummy = 0;
+                    sal_uInt32 nDummy = 0;
                     Respond( pMessage->m_nID,
                              (char*)&aRet, sizeof( aRet ),
                              "", 0,
-                             &nDummy, sizeof(UINT32),
-                             &nDummy, sizeof(UINT32),
+                             &nDummy, sizeof(sal_uInt32),
+                             &nDummy, sizeof(sal_uInt32),
                              NULL );
                 }
                 else
                 {
                     m_aNPWrapStreams.push_back( pStream );
 
-                    ULONG nLen = strlen( pStream->url );
+                    sal_uLong nLen = strlen( pStream->url );
                     Respond( pMessage->m_nID,
                              (char*)&aRet, sizeof( aRet ),
                              pStream->url, nLen,
-                             &pStream->end, sizeof(UINT32),
-                             &pStream->lastmodified, sizeof(UINT32),
+                             &pStream->end, sizeof(sal_uInt32),
+                             &pStream->lastmodified, sizeof(sal_uInt32),
                              NULL );
                 }
                 
@@ -207,11 +205,11 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_PostURLNotify:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 char* pUrl		= pMessage->GetString();
                 char* pTarget	= pMessage->GetString();
-                UINT32 nLen		= pMessage->GetUINT32();
+                sal_uInt32 nLen		= pMessage->GetUINT32();
                 char* pBuf		= (char*)pMessage->GetBytes();
                 NPBool* pFile	= (NPBool*)pMessage->GetBytes();
                 void** pNData	= (void**)pMessage->GetBytes();
@@ -227,11 +225,11 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_PostURL:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 char* pUrl		= pMessage->GetString();
                 char* pWindow	= pMessage->GetString();
-                UINT32 nLen		= pMessage->GetUINT32();
+                sal_uInt32 nLen		= pMessage->GetUINT32();
                 char* pBuf		= (char*)pMessage->GetBytes();
                 NPBool* pFile	= (NPBool*)pMessage->GetBytes();
                 NPError aRet =
@@ -245,14 +243,14 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_RequestRead:
             {
-                UINT32 nFileID		= pMessage->GetUINT32();
+                sal_uInt32 nFileID		= pMessage->GetUINT32();
                 NPStream* pStream	= m_aNPWrapStreams[ nFileID ];
-                UINT32 nRanges		= pMessage->GetUINT32();
-                UINT32* pArray		= (UINT32*)pMessage->GetBytes();
+                sal_uInt32 nRanges		= pMessage->GetUINT32();
+                sal_uInt32* pArray		= (sal_uInt32*)pMessage->GetBytes();
                 // build ranges table
                 NPByteRange* pFirst = new NPByteRange;
                 NPByteRange* pRun	= pFirst;
-                for( UINT32 n = 0; n < nRanges; n++ )
+                for( sal_uInt32 n = 0; n < nRanges; n++ )
                 {
                     pRun->offset = pArray[ 2*n ];
                     pRun->length = pArray[ 2*n+1 ];
@@ -272,7 +270,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_Status:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 char* pString	= pMessage->GetString();
                 NPN_Status( instance, pString );
@@ -293,13 +291,13 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_Write:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
-                UINT32 nFileID		= pMessage->GetUINT32();
+                sal_uInt32 nFileID		= pMessage->GetUINT32();
                 NPStream* pStream	= m_aNPWrapStreams[ nFileID ];
-                INT32 nLen			= pMessage->GetUINT32();
+                sal_Int32 nLen			= pMessage->GetUINT32();
                 void* pBuffer		= pMessage->GetBytes();
-                INT32 nRet = NPN_Write( instance, pStream, nLen, pBuffer );
+                sal_Int32 nRet = NPN_Write( instance, pStream, nLen, pBuffer );
                 Respond( pMessage->m_nID,
                          (char*)&nRet, sizeof( nRet ),
                          NULL );
@@ -309,7 +307,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
             break;
             case eNPN_UserAgent:
             {
-                UINT32 nInstance	= pMessage->GetUINT32();
+                sal_uInt32 nInstance	= pMessage->GetUINT32();
                 NPP instance		= m_aInstances[ nInstance ]->instance;
                 const char* pAnswer = NPN_UserAgent( instance );
                 Respond( pMessage->m_nID,
@@ -327,7 +325,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
 }
 
 #define GET_INSTANCE() \
-    UINT32 nInstance;  \
+    sal_uInt32 nInstance;  \
     nInstance = GetNPPID( instance );
 
 #define GET_INSTANCE_RET( err ) \
@@ -357,9 +355,9 @@ NPError UnxPluginComm::NPP_Destroy( NPP instance, NPSavedData** save )
         return NPERR_GENERIC_ERROR;
 
     aRet = GetNPError( pMes );
-    ULONG nSaveBytes;
+    sal_uLong nSaveBytes;
     void* pSaveData = pMes->GetBytes( nSaveBytes );
-    if( nSaveBytes == 4 && *(UINT32*)pSaveData == 0 )
+    if( nSaveBytes == 4 && *(sal_uInt32*)pSaveData == 0 )
         *save = NULL;
     else
     {
@@ -376,7 +374,7 @@ NPError UnxPluginComm::NPP_DestroyStream( NPP instance, NPStream* stream, NPErro
 {
     NPError aRet = NPERR_GENERIC_ERROR;
     GET_INSTANCE_RET( aRet );
-    UINT32 nFileID = GetStreamID( stream );
+    sal_uInt32 nFileID = GetStreamID( stream );
     if( nFileID == PluginConnector::UnknownStreamID )
         return NPERR_GENERIC_ERROR;
     
@@ -533,7 +531,7 @@ void UnxPluginComm::NPP_Shutdown()
 void UnxPluginComm::NPP_StreamAsFile( NPP instance, NPStream* stream, const char* fname )
 {
     GET_INSTANCE();
-    UINT32 nFileID = GetStreamID( stream );
+    sal_uInt32 nFileID = GetStreamID( stream );
     if( nFileID == PluginConnector::UnknownStreamID )
         return;
 
@@ -559,7 +557,7 @@ void UnxPluginComm::NPP_URLNotify( NPP instance, const char* url, NPReason reaso
 int32 UnxPluginComm::NPP_Write( NPP instance, NPStream* stream, int32 offset, int32 len, void* buffer )
 {
     GET_INSTANCE_RET( -1 );
-    UINT32 nFileID = GetStreamID( stream );
+    sal_uInt32 nFileID = GetStreamID( stream );
     if( nFileID == PluginConnector::UnknownStreamID )
         return -1;
 
@@ -582,7 +580,7 @@ int32 UnxPluginComm::NPP_Write( NPP instance, NPStream* stream, int32 offset, in
 int32 UnxPluginComm::NPP_WriteReady( NPP instance, NPStream* stream )
 {
     GET_INSTANCE_RET( -1 );
-    UINT32 nFileID = GetStreamID( stream );
+    sal_uInt32 nFileID = GetStreamID( stream );
     if( nFileID == PluginConnector::UnknownStreamID )
         return -1;
 
