@@ -82,7 +82,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::XSDValidationHelper: caught an exception while examining the introspectee!" );
+            OSL_FAIL( "XSDValidationHelper::XSDValidationHelper: caught an exception while examining the introspectee!" );
         }
     }
 
@@ -103,7 +103,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::getAvailableDataTypeNames: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::getAvailableDataTypeNames: caught an exception!" );
         }
     }
 
@@ -160,7 +160,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::getValidatingDataTypeName: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::getValidatingDataTypeName: caught an exception!" );
         }
         return sDataTypeName;
     }
@@ -182,7 +182,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::getDataTypeByName: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::getDataTypeByName: caught an exception!" );
         }
 
         return pReturn;
@@ -217,7 +217,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::cloneDataType: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::cloneDataType: caught an exception!" );
         }
         return true;
     }
@@ -234,7 +234,7 @@ namespace pcr
 
             if ( !xRepository->hasByName( _rName ) )
             {
-                OSL_ENSURE( sal_False, "XSDValidationHelper::removeDataTypeFromRepository: invalid repository and/or data type!" );
+                OSL_FAIL( "XSDValidationHelper::removeDataTypeFromRepository: invalid repository and/or data type!" );
                 return false;
             }
 
@@ -242,7 +242,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::removeDataTypeFromRepository: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::removeDataTypeFromRepository: caught an exception!" );
             return false;
         }
         return true;
@@ -322,7 +322,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::copyDataType: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::copyDataType: caught an exception!" );
         }
     }
 
@@ -374,7 +374,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::findDefaultFormatForIntrospectee: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::findDefaultFormatForIntrospectee: caught an exception!" );
         }
     }
 
@@ -401,7 +401,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "XSDValidationHelper::getBasicTypeNameForClass: caught an exception!" );
+            OSL_FAIL( "XSDValidationHelper::getBasicTypeNameForClass: caught an exception!" );
         }
 
         return sReturn;
