@@ -33,7 +33,6 @@
 #include<osl/module.hxx>
 #include <osl/time.h>
 #include <rtl/ustring.hxx>
-#include <stdio.h>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/servicefactory.hxx>
 #include <cppuhelper/bootstrap.hxx>
@@ -172,18 +171,6 @@ sal_Bool test3()
     Reference<XComponent> xcomp( context, UNO_QUERY);
     xcomp->dispose();
 
-//	for (int i=0; i < 10; i++)
-//	{	
-//		Reference<XSimpleRegistry> xreg= createSimpleRegistry();
-//		xreg->open( OUString( RTL_CONSTASCII_USTRINGPARAM("applicat.rdb")),
-//							   sal_False, sal_False );
-//		Reference< XComponentContext > context= bootstrap_InitialComponentContext(xreg);	
-//		Reference<XComponent> xcomp( context, UNO_QUERY);
-//		xcomp->dispose();
-//
-//	}
-
-//	return sal_True;
     return bTest1 && bTest2;
 }
 
