@@ -51,10 +51,8 @@
 
 #include "factory.hxx"
 
-using namespace rtl;
 using namespace usr;
 
-
 #define BUILD_ERROR(expr, Message)\
         {\
             m_seqErrors.realloc( m_seqErrors.getLen() + 1 ); \
@@ -109,13 +107,9 @@ using namespace usr;
 
 /****
 * test szenarios :
-*
-*
-*
 ****/
 
 
-
 class OSaxParserTest :
         public XSimpleTest,
         public OWeakObject
@@ -165,8 +159,6 @@ private:
 
 /**
 * for external binding
-*
-*
 **/
 XInterfaceRef OSaxParserTest_CreateInstance( const XMultiServiceFactoryRef & rSMgr ) THROWS((Exception))
 {
