@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,19 +34,19 @@
 #include <stardiv/uno/beans/exactname.hxx>
 
 #include <rtl/ustring.hxx>
-#include <vos/dynload.hxx>
-#include <vos/diagnose.hxx>
+#include <osl/diagnose.h>
 #include <usr/services.hxx>
 #include <vcl/svapp.hxx>
 #include <usr/ustring.hxx>
 #include <usr/weak.hxx>
 #include <tools/string.hxx>
-#include <vos/conditn.hxx>
+#include <osl/conditn.hxx>
 
-using namespace rtl;
-using namespace vos;
 using namespace usr;
 
+using ::rtl::StringToOUString;
+using ::rtl::OUStringToString;
+
 #define PCHAR_TO_USTRING(x) StringToOUString(String(x),CHARSET_SYSTEM)
 #define USTRING_TO_PCHAR(x) OUStringToString(x , CHARSET_DONTKNOW ).GetCharStr()
 
@@ -278,7 +279,7 @@ public:
     void cmdLine();
 protected:
 
-    OCondition m_aDebugCondition;
+    osl::Condition m_aDebugCondition;
     XDebuggingRef *m_pDebuggingRef;
 };
 
@@ -621,3 +622,4 @@ int __LOADONCALLAPI main (int argc, char **argv)
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
