@@ -64,8 +64,8 @@ namespace frm
     //---------------------------------------------------------------------
     static const Locale& getLocale(LocaleType _eType)
     {
-        static const Locale s_aEnglishUS( ::rtl::OUString::createFromAscii("en"), ::rtl::OUString::createFromAscii("us"), ::rtl::OUString() );
-        static const Locale s_aGerman( ::rtl::OUString::createFromAscii("de"), ::rtl::OUString::createFromAscii("DE"), ::rtl::OUString() );
+        static const Locale s_aEnglishUS( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("en") ), ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("us") ), ::rtl::OUString() );
+        static const Locale s_aGerman( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("de") ), ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DE") ), ::rtl::OUString() );
         static const ::rtl::OUString s_sEmptyString;
         static const Locale s_aSystem( s_sEmptyString, s_sEmptyString, s_sEmptyString );
 
@@ -81,7 +81,7 @@ namespace frm
                 return s_aSystem;
         }
 
-        OSL_ENSURE(sal_False, "getLocale: invalid enum value!");
+        OSL_FAIL("getLocale: invalid enum value!");
         return s_aSystem;
     }
 
@@ -135,7 +135,7 @@ namespace frm
             }
         }
 
-        OSL_ENSURE(sal_False, "lcl_getFormatTable: invalid id!");
+        OSL_FAIL("lcl_getFormatTable: invalid id!");
         return NULL;
     }
 
@@ -199,7 +199,7 @@ namespace frm
                             }
                             catch(const Exception&)
                             {
-                                OSL_ENSURE(sal_False, "OLimitedFormats::ensureTableInitialized: adding the key to the formats collection failed!");
+                                OSL_FAIL("OLimitedFormats::ensureTableInitialized: adding the key to the formats collection failed!");
                             }
 #endif
                         }
@@ -243,7 +243,7 @@ namespace frm
             }
             catch(const Exception&)
             {
-                OSL_ENSURE(sal_False, "OLimitedFormats::setAggregateSet: invalid handle!");
+                OSL_FAIL("OLimitedFormats::setAggregateSet: invalid handle!");
             }
         }
 #endif
@@ -342,7 +342,7 @@ namespace frm
 
             if (!bFoundIt)
             {	// somebody gave us an format which we can't translate
-                ::rtl::OUString sMessage = ::rtl::OUString::createFromAscii("This control supports only a very limited number of formats.");
+                ::rtl::OUString sMessage (RTL_CONSTASCII_USTRINGPARAM("This control supports only a very limited number of formats.") );
                 throw IllegalArgumentException(sMessage, NULL, 2);
             }
 
