@@ -40,11 +40,13 @@
 #include <comphelper/documentconstants.hxx>
 #include <comphelper/attributelist.hxx>
 
-using namespace rtl;
 using namespace com::sun::star::beans;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::xml::sax;
 
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+
 ManifestExport::ManifestExport(Reference < XDocumentHandler > xHandler,  const Sequence < Sequence < PropertyValue > > &rManList )
 {
     const OUString sFileEntryElement   	( RTL_CONSTASCII_USTRINGPARAM ( ELEMENT_FILE_ENTRY ) );
@@ -159,6 +161,7 @@ ManifestExport::ManifestExport(Reference < XDocumentHandler > xHandler,  const S
             {
                 // this is ODF12 generation, let encrypted streams contain start-key-generation entry
                 bStoreStartKeyGeneration = sal_True;
+                pRootAttrList->AddAttribute ( sVersionAttribute, sCdataAttribute, aDocVersion );
             }
         }
         else
