@@ -66,7 +66,6 @@ sub usage
 {
     print <<Ende;
 ----------------------------------------------------------------------
-$prog V1.0 (c) Sun Microsystems 2009
 This program installs a Windows Installer installation set
 without using msiexec.exe. The installation is comparable
 with an administrative installation using the Windows Installer
@@ -1128,7 +1127,7 @@ sub register_extensions_sync
 
     $preregdir =~ s/\/\s*$//g;
     
-    my $systemcall = $executable . " sync --verbose -env:BUNDLED_EXTENSIONS_USER=\"file:///" . $preregdir . "\"" . " -env:UserInstallation=file:///" . $localtemppath . " 2\>\&1 |";
+    my $systemcall = $executable . " sync --verbose 2\>\&1 |";
 
     print "... $systemcall\n";
 
