@@ -36,13 +36,9 @@
 #include "nss.h"
 #include "secder.h"
 
-//MM : added by MM
 #include "hasht.h"
 #include "secoid.h"
 #include "pk11func.h"
-//MM : end
-
-
 
 #include <sal/config.h>
 #include <rtl/uuid.h>
@@ -331,7 +327,6 @@ X509Certificate_NssImpl* X509Certificate_NssImpl :: getImplementation( const Ref
         return NULL ;
 }
 
-// MM : added by MM
 ::rtl::OUString getAlgorithmDescription(SECAlgorithmID *aid)
 {
     SECOidTag tag;
@@ -347,23 +342,15 @@ X509Certificate_NssImpl* X509Certificate_NssImpl :: getImplementation( const Ref
     if( pCert != NULL )
     {
         unsigned char fingerprint[20];
-        //char *fpStr = NULL;
-        SECItem fpItem;
         int length = ((id == SEC_OID_MD5)?MD5_LENGTH:SHA1_LENGTH);
         
         memset(fingerprint, 0, sizeof fingerprint);
         PK11_HashBuf(id, fingerprint, pCert->derCert.data, pCert->derCert.len);
-        fpItem.data = fingerprint;
-        fpItem.len = length;
-        //fpStr = CERT_Hexify(&fpItem, 1);
     
         Sequence< sal_Int8 > thumbprint( length ) ;
         for( int i = 0 ; i < length ; i ++ )
-        {
             thumbprint[i] = fingerprint[i];
-        }
         
-        //PORT_Free(fpStr);
         return thumbprint;
     }
     else
@@ -466,6 +453,4 @@ sal_Int32 SAL_CALL X509Certificate_NssImpl::getCertificateUsage(  )
     return usage;
 }
 
-// MM : end
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
