@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,9 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_xmlsecurity.hxx"
 
-#include <stdio.h>
-#include <string.h>
-
 #include <rtl/ustring.hxx>
 #include <cppuhelper/bootstrap.hxx>
 #include <cppuhelper/servicefactory.hxx>
@@ -60,7 +58,6 @@
 #include <com/sun/star/xml/crypto/sax/XSecuritySAXEventKeeper.hpp>
 #include <com/sun/star/xml/crypto/sax/XReferenceResolvedListener.hpp>
 #include <com/sun/star/xml/crypto/XXMLSignature.hpp>
-#include <com/sun/star/xml/wrapper/XXMLDocumentWrapper.hpp>
 #include <com/sun/star/xml/csax/XMLAttribute.hpp>
 #include <com/sun/star/xml/crypto/XSEInitializer.hpp>
 #include <com/sun/star/xml/crypto/SecurityOperationStatus.hpp>
@@ -79,23 +76,15 @@
 
 #include <xmloff/attrlist.hxx>
 
-//#include <malloc.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-/*
- * Can not build under solaris.
- * Delete the memory.h including by AF
-#include <memory.h>
-*/
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <osl/time.h>
 
 
-
 #ifndef INCLUDED_VECTOR
 #include <vector>
 #define INCLUDED_VECTOR
@@ -476,16 +465,16 @@ rtl::OUString XSecTester::parseFile(
         
         if (bIsJavaBased)
         {
-            SEInitializer_comp = rtl::OUString::createFromAscii( SEINITIALIZER_JAVA_COMPONENT );
-            XMLSignature_comp = rtl::OUString::createFromAscii( XMLSIGNATURE_JAVA_COMPONENT);
-            m_ouXMLDocumentWrapperComponentName = rtl::OUString::createFromAscii( XMLDOCUMENTWRAPPER_JAVA_COMPONENT );
+            SEInitializer_comp = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SEINITIALIZER_JAVA_COMPONENT ));
+            XMLSignature_comp = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( XMLSIGNATURE_JAVA_COMPONENT));
+            m_ouXMLDocumentWrapperComponentName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( XMLDOCUMENTWRAPPER_JAVA_COMPONENT ));
             tokenPath = m_ouJavaCryptokenDir;
         }
         else
         {
-            SEInitializer_comp = rtl::OUString::createFromAscii( SEINITIALIZER_C_COMPONENT );
-            XMLSignature_comp = rtl::OUString::createFromAscii( XMLSIGNATURE_C_COMPONENT);
-            m_ouXMLDocumentWrapperComponentName = rtl::OUString::createFromAscii( XMLDOCUMENT_C_COMPONENT );
+            SEInitializer_comp = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SEINITIALIZER_C_COMPONENT ));
+            XMLSignature_comp = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( XMLSIGNATURE_C_COMPONENT));
+            m_ouXMLDocumentWrapperComponentName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( XMLDOCUMENT_C_COMPONENT ));
             tokenPath = m_ouCCryptokenDir;
         }
         
@@ -591,13 +580,13 @@ rtl::OUString XSecTester::parseFile(
         }
         else
         {
-            ouMessage += rtl::OUString::createFromAscii( "N/A" );
+            ouMessage += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("N/A"));
         }
         
     }
     else
     {
-        ouMessage += rtl::OUString::createFromAscii( "-" );
+        ouMessage += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-"));
     }
     
     return ouMessage;
@@ -743,7 +732,7 @@ rtl::OUString SAL_CALL XSecTester::transfer_without_sec(
                 xJavaFilterParser, cssu::UNO_QUERY );
 
             if ( !xJavaFilterParser.is() )
-                return rtl::OUString::createFromAscii( "NO JAVA" );
+                return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("NO JAVA"));
 
             /* connect the SAX Parser, the Java Flat Filter and the SAX Writer */
             xJavaFilterParser->setDocumentHandler( xSaxWriterHandler );
@@ -897,7 +886,7 @@ SignatureEntity::SignatureEntity(
         m_xSAXEventKeeper->setSecurityId(m_nSignatureElementCollectorId, m_nSecurityId);
 
         m_xReferenceListener = cssu::Reference< cssxc::sax::XReferenceResolvedListener >(
-            mxMSF->createInstance( rtl::OUString::createFromAscii( SIGNATURECREATOR_COMPONENT )),
+            mxMSF->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SIGNATURECREATOR_COMPONENT ))),
             cssu::UNO_QUERY);
 
         cssu::Reference<cssl::XInitialization> xInitialization(m_xReferenceListener, cssu::UNO_QUERY);
@@ -936,7 +925,7 @@ SignatureEntity::SignatureEntity(
         m_xSAXEventKeeper->setSecurityId(m_nSignatureElementCollectorId, m_nSecurityId);
 
         m_xReferenceListener = cssu::Reference< cssxc::sax::XReferenceResolvedListener >(
-            mxMSF->createInstance( rtl::OUString::createFromAscii( SIGNATUREVERIFIER_COMPONENT )),
+            mxMSF->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SIGNATUREVERIFIER_COMPONENT ))),
             cssu::UNO_QUERY);	
         
         cssu::Reference<cssl::XInitialization> xInitialization(m_xReferenceListener, cssu::UNO_QUERY);
@@ -1193,7 +1182,7 @@ bool XSecTester::foundSecurityRelated()
              cssu::UNO_QUERY);
 
         m_xSAXEventKeeper = cssu::Reference< cssxc::sax::XSecuritySAXEventKeeper >
-            (mxMSF->createInstance( rtl::OUString::createFromAscii( SAXEVENTKEEPER_COMPONENT )),
+            (mxMSF->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SAXEVENTKEEPER_COMPONENT ))),
              cssu::UNO_QUERY);
 
         cssu::Reference<cssl::XInitialization> xInitialization(m_xSAXEventKeeper,  cssu::UNO_QUERY);
@@ -1291,9 +1280,9 @@ void XSecTester::findKeyOrReference(SecurityEntity* pSecurityEntity, const rtl::
             {
                 (*ii_referenceRefNums) = nRefNum;
 
-                ii_referenceURIs++;
-                ii_referenceKeeperIds++;
-                ii_referenceRefNums++;
+                ++ii_referenceURIs;
+                ++ii_referenceKeeperIds;
+                ++ii_referenceRefNums;
             }
             
             if (bIsFindingKey)
@@ -1303,9 +1292,9 @@ void XSecTester::findKeyOrReference(SecurityEntity* pSecurityEntity, const rtl::
         }
         else 
         {
-            ii_referenceURIs++;
-            ii_referenceKeeperIds++;
-            ii_referenceRefNums++;
+            ++ii_referenceURIs;
+            ++ii_referenceKeeperIds;
+            ++ii_referenceRefNums;
         }
     }
 }
@@ -1617,7 +1606,7 @@ std::vector< AncestorEvent* >::const_iterator XSecTester::checkAncestorStartElem
         
         if (next != m_vAncestorEvents.end())
         {
-            next++;
+            ++next;
         }
     }
     
@@ -1644,7 +1633,7 @@ void XSecTester::flushAncestorEvents(
             else
             {
                 sendAncestorEndElementEvent((*ii)->ouName, xDocumentHandler);
-                ii++;
+                ++ii;
             }
         }
     }
@@ -1779,7 +1768,7 @@ int main( int argc, char **argv )
              * export the file with signautre/encryption (C++)
              */
             outputFileName1 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-ex.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-ex.xml"));
             ouTime_C = pTester->export_xml(ouInputFileName, outputFileName1, sal_False);
             nPosition1 = ouTime_C.lastIndexOf('\t');
             ouRemark_C = ouTime_C.copy(nPosition1 + 1);
@@ -1789,7 +1778,7 @@ int main( int argc, char **argv )
              * export the file with signautre/encryption (Java)
              */
             outputFileName1 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-ex2.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-ex2.xml"));
             ouTime_Java = pTester->export_xml(ouInputFileName, outputFileName1, sal_True);
             nPosition1 = ouTime_Java.lastIndexOf('\t');
             ouRemark_Java = ouTime_Java.copy(nPosition1 + 1);
@@ -1799,14 +1788,14 @@ int main( int argc, char **argv )
              * export the file without signautre/encryption
              */
             outputFileName2 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-ex-no.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-ex-no.xml"));
             ouTime_NoSecurity = pTester->transfer_without_sec(ouInputFileName, outputFileName2, sal_False);
 
             /*
              * export the file with Java Flat Filter
              */
             outputFileName2 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-ex-jf.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-ex-jf.xml"));
             ouTime_JavaForwardOnly = pTester->transfer_without_sec(ouInputFileName, outputFileName2, sal_True);
             
             /*
@@ -1829,7 +1818,7 @@ int main( int argc, char **argv )
              * import the file with signautre/encryption (C++)
              */
             outputFileName1 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-im.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-im.xml"));
             ouTime_C = pTester->import_xml(ouInputFileName, outputFileName1, sal_False);
             nPosition1 = ouTime_C.lastIndexOf('\t');
             ouRemark_C = ouTime_C.copy(nPosition1 + 1);
@@ -1839,7 +1828,7 @@ int main( int argc, char **argv )
              * import the file with signautre/encryption (Java)
              */
             outputFileName1 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-im2.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-im2.xml"));
             ouTime_Java = pTester->import_xml(ouInputFileName, outputFileName1, sal_True);
             nPosition1 = ouTime_Java.lastIndexOf('\t');
             ouRemark_Java = ouTime_Java.copy(nPosition1 + 1);
@@ -1849,7 +1838,7 @@ int main( int argc, char **argv )
              * import the file without signautre/encryption
              */
             outputFileName2 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-im-no.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-im-no.xml"));
             ouTime_NoSecurity = pTester->transfer_without_sec(ouInputFileName, outputFileName2, sal_False);
 
             /*
@@ -1857,7 +1846,7 @@ int main( int argc, char **argv )
              */
 
             outputFileName2 = ouInputFileName.copy(0, nPosition) + 
-                rtl::OUString::createFromAscii("-im-jf.xml");
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-im-jf.xml"));
             ouTime_JavaForwardOnly = pTester->transfer_without_sec(ouInputFileName, outputFileName2, sal_True);
             
             /*
@@ -1878,3 +1867,5 @@ int main( int argc, char **argv )
 
     return 0;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
